********************************************************************************
// Purpose: Create combined dataset for Congressional Explorer
// Author: Jared Colston
// Last Updated: 1.19.2024
// Last Updated By: Jared Colston
********************************************************************************

clear all

********************************************************************************
**# [i] DEPENDENCIES ----------------------------------------------------------|
/* 	All data source files will need to be run in order for this file to 
	work properly. This file incorporates previous panel datasets from 
	IPEDS, Scorecard, FSA, and ACS. Please run the following 
	files in the zipped folder first before this file:
		ipeds_dataclean.do
		scorecard_dataclean.do
		fsa_dataclean.do
		acs_dataclean.do
	*/
	
********************************************************************************
**# [ii] USER-WRITTEN COMMANDS ------------------------------------------------|

	/*
		ssc install mdesc, replace
		ssc install frameappend, replace
	*/

********************************************************************************
**# [1] FILE PATHWAYS ---------------------------------------------------------|
	
	global analysis "C:\Users\jared\Desktop\work\pnpi\data\combined"
	
********************************************************************************
**# [2] COMBINE INSTITUTION-LEVEL DATA ----------------------------------------|

// Start with IPEDS
	use "C:\Users\jared\Desktop\work\pnpi\data\ipeds\ipeds_2011_2021.dta", clear
	
// Merge with Scorecard
	merge 1:1 unitid year using "C:\Users\jared\Desktop\work\pnpi\data\scorecard\scorecard_cleaned.dta"
		* ~150 from IPEDS and 500 from scorecard not matching
		* institutions vary in sector (weird quirks like with purdue polytech)
		* no scorecard insts report enrollment, ipeds report tiny enroll
		* I think safe to drop non-matches

	drop if _merge == 2 															// drop non-matches from scorecard because no cong dist
	
	drop if inlist(opeid,"-2")														// Drop out of universe institutions
	drop if distanceonly == 1														// Drop exclusively online institutions 
	drop distanceonly
	drop _merge
	drop bbrr2_*_supp																// suppressed data

	*unify OPEIDs for FSA merge
		gen opeid2 = substr(8 * "0", 1, 8 - length(opeid)) + opeid if opeid != ""
	
// Merge with FSA 
	merge m:1 opeid2 year using "C:\Users\jared\Desktop\work\pnpi\data\fsa\fsa_cleaned.dta"
	drop if _merge == 2																// Mostly foreign campuses or fps
		// Non foreign campuses = 68; many were exclusively online
	drop _merge
	
********************************************************************************
**# [3] APPLY EXCLUSION CRITERIA ----------------------------------------------|

	// Drop sovereign countries that aren't represented in congress (Micronesia, Marshall Islands, Palau)
		drop if inlist(stabbr,"FM","MH","PW")
	
	// Limit data to only NCES Digest institutions
		recode deggrant (-3=.) (2=0)
		*lab define deggrant_lab 0 "Non-Degree-Granting" 1 "Degree-Granting"
		*lab val deggrant deggrant_lab
		keep if deggrant == 1 & inlist(pset4flg,1,3)
			
	// Examine and remove predominantly online institutions 
		ds dist_*
		foreach x in `r(varlist)' {
			recode `x' (. = 0)
		}
		
		gen pct_dist_excl = dist_excl / dist_denom
		gen pct_dist_excl_ug = dist_excl_ug / dist_denom_ug
		gen pct_dist_excl_gr = dist_excl_gr / dist_denom_gr
		
		/* ONLY UN-COMMENT WHEN NEEDING TO LOOK AT ONLINE ENROLLMENT
		hist pct_dist_excl if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3), ///
			freq bins(20) addlabels name(tot_all, replace) color(eltblue) ///
			title("All students All Sectors", size(medsmall)) nodraw
		hist pct_dist_excl_ug if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3), ///
			freq bins(20) addlabels name(ug_all, replace) color(eltblue) ///
			title("Undergraduates All Sectors", size(medsmall)) nodraw
		hist pct_dist_excl_gr if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3), ///
			freq bins(20) addlabels name(gr_all, replace) color(eltblue) ///
			title("Graduates All Sectors", size(medsmall)) nodraw
		graph combine tot_all ug_all gr_all, name(comb_all, replace)
		
		hist pct_dist_excl if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,1), ///
			freq bins(20) addlabels name(tot_pub4, replace) color(eltgreen) ///
			title("All students Pub 4-Yrs", size(medsmall)) nodraw
		hist pct_dist_excl_ug if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,1), ///
			freq bins(20) addlabels name(ug_pub4, replace) color(eltgreen) ///
			title("Undergraduates Pub 4-Yrs", size(medsmall)) nodraw
		hist pct_dist_excl_gr if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,1), ///
			freq bins(20) addlabels name(gr_pub4, replace) color(eltgreen) ///
			title("Graduates Pub 4-Yrs", size(medsmall)) nodraw
		graph combine tot_pub4 ug_pub4 gr_pub4, name(comb_pub4, replace)
		
		hist pct_dist_excl if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,4,7), ///
			freq bins(20) addlabels name(tot_pub2, replace) color(erose) ///
			title("All students Pub 2-Yrs", size(medsmall)) nodraw
		hist pct_dist_excl_ug if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,4,7), ///
			freq bins(20) addlabels name(ug_pub2, replace) color(erose) ///
			title("Undergraduates Pub 2-Yrs", size(medsmall)) nodraw
		hist pct_dist_excl_gr if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,4,7), ///
			freq bins(20) addlabels name(gr_pub2, replace) color(erose) ///
			title("Graduates Pub 2-Yrs", size(medsmall)) nodraw
		graph combine tot_pub2 ug_pub2 gr_pub2, name(comb_pub2, replace)
		
		hist pct_dist_excl if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,2,5,8), ///
			freq bins(20) addlabels name(tot_np, replace) color(edkblue) ///
			title("All students Non-Profit", size(medsmall)) nodraw
		hist pct_dist_excl_ug if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,2,5,8), ///
			freq bins(20) addlabels name(ug_np, replace) color(edkblue) ///
			title("Undergraduates Non-Profit", size(medsmall)) nodraw
		hist pct_dist_excl_gr if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,2,5,8), ///
			freq bins(20) addlabels name(gr_np, replace) color(edkblue) ///
			title("Graduates Non-Profit", size(medsmall)) nodraw
		graph combine tot_np ug_np gr_np, name(comb_np, replace)
		
		hist pct_dist_excl if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,3,6,9), ///
			freq bins(20) addlabels name(tot_fp, replace) color(teal) ///
			title("All students For-Profit", size(medsmall)) nodraw
		hist pct_dist_excl_ug if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,3,6,9), ///
			freq bins(20) addlabels name(ug_fp, replace) color(teal) ///
			title("Undergraduates For-Profit", size(medsmall)) nodraw
		hist pct_dist_excl_gr if year == "2019" & deggrant == 1 & inlist(pset4flg,1,3) & inlist(sector,3,6,9), ///
			freq bins(20) addlabels name(gr_fp, replace) color(teal) ///
			title("Graduates For-Profit", size(medsmall)) nodraw
		graph combine tot_fp ug_fp gr_fp, name(comb_fp, replace)
		*/
		
		gen online_tag = 1 if year == "2019" & ///									// Remove institutions with 2/3 of UG enroll exclusively online; ignore Penn State
			!regexm(instnm, "Pennsylvania State University") & ///
			pct_dist_excl_ug >= .66 & pct_dist_excl_ug != .
			
		egen online_tag_max = max(online_tag), by(unitid)							// Make sure removed for all years
		drop if online_tag_max == 1
		drop online_tag online_tag_max

	
********************************************************************************
**# [4] CORRECT FOR CHANGING CONGRESSIONAL DISTRICTS, USE MOST RECENT ---------|
	/*
	preserve 
		keep if year == "2021"
		keep unitid instnm stabbr fips address cngdstcd
		gen addr_dup = address 
		replace addr_dup = subinstr(addr_dup," ","%20",.)
		cd "C:\Users\jared\Desktop\work\pnpi\data\cng_json"
		save "congdist_correction_start.dta", replace

		local tot = _N
		forvalues y = 1/`tot' {
			use "congdist_correction_start.dta", clear
			keep if _n == `y'
			local address = addr_dup[1]
			local unitid = unitid[1]
			frame create frame_obs_`y'
			frame change frame_obs_`y'
			di "`y'"
			di "`address'"
			capture jsonio kv, file("https://civicinfo.googleapis.com/civicinfo/v2/representatives?address=`address'&key=$googleapi_civic")
			capture jsonio out, what(data) file("json_district_`unitid'.json")
			frame change default
			frame drop frame_obs_`y'
			sleep 2000
		}
	restore
	
	preserve
		cd "C:\Users\jared\Desktop\work\pnpi\data\cng_json"
		use "congdist_correction_start.dta", replace
		levelsof unitid, local(unitids)
		frame create new_dists
		frame change new_dists
		set obs 1
		gen v1 = ""
		gen unitid = ""
		local x = 1
		foreach y of local unitids {
			frame create frame_obs_`y'
			frame change frame_obs_`y'
			filefilter "json_district_`y'.json" "json_district_`y'.txt", from("}, {") to (\r) replace
			import delimited "json_district_`y'.txt", delim("\t") stripquotes(no) clear
			keep if regexm(v1, "[cC]ongressional")
			if (_N == 0) {
				set obs 1
				replace v1 = "EMPTY"
			}
			duplicates drop v1, force
			replace v1 = subinstr(v1,`"""',"",.)
			replace v1 = subinstr(v1,"value : ","",.)
			replace v1 = subinstr(v1,",","",.)
			replace v1 = trim(v1)
			gen unitid = "`y'"
			local ++x
			format v1 %70s			
			frame change new_dists
			frameappend frame_obs_`y', drop
		}
		
		drop if v1 == ""
		destring unitid, replace
		save "congdist_correction_mid.dta", replace
	restore
	
	preserve
		cd "C:\Users\jared\Desktop\work\pnpi\data\cng_json"
		use "congdist_correction_start.dta", replace
		merge 1:1 unitid using "congdist_correction_mid.dta"
		drop _merge
		gen v2 = regexs(1) if regexm(v1, "([0-9][0-9]*)")
		replace v2 = "00" if regexm(v1, "at-large")
		replace v2 = substr(2 * "0", 1, 2 - length(v2)) + v2
		gen v3 = string(fips) + v2
		drop v2
		rename (v1 v3) (new_dist new_cd)
		destring new_cd, replace
		order unitid instnm stabbr fips cngdstcd new_cd new_dist
		gen dup_check = "BAD"
		replace dup_check = "GOOD" if cngdstcd == new_cd
		keep unitid new_cd new_dist dup_check
		save "congdist_correction_end.dta", replace
	restore
	*/
	
	merge m:1 unitid using "C:\Users\jared\Desktop\work\pnpi\data\cng_json\congdist_correction_end.dta"
	drop if _merge == 2																// Lingering from exclusion criteria
	drop _merge
	
	tab new_dist if year =="2021" & new_dist == "EMPTY" 							// 198 API errors
	tab stabbr control if year =="2021" & new_dist == "EMPTY"						// Concentrated in large states & in np/fp
	
	// Manually replace those with a single CD
		replace new_dist = "North Dakota's at-large congressional district" ///
			if stabbr == "ND" & new_dist == "EMPTY" & year == "2021"
		
		replace new_dist = "Vermont's at-large congressional district" ///
			if stabbr == "VT" & new_dist == "EMPTY" & year == "2021"
			
	// Export frame of remaining 183 locations to manually change 
		frame put unitid instnm fips address stabbr control cngdstcd new_cd new_dist ///
			if year == "2021" & new_dist == "EMPTY", into(manual_cng_input)
			
		frame change manual_cng_input 
		export excel "C:\Users\jared\Desktop\work\pnpi\data\cng_json\manual_cng_input.xlsx", firstrow(var) replace
		// Manually changed cds and saved as new var 
		import excel "C:\Users\jared\Desktop\work\pnpi\data\cng_json\manual_cng_input_changed.xlsx", firstrow clear
		tempfile input_changed
		save `input_changed'
		frame change default
		merge m:1 unitid using `input_changed', keepusing(manual_cd)
		drop _merge
		
		replace dup_check = "BAD" if year == "2021" & new_dist == "EMPTY" & cngdstcd != manual_cd
		replace dup_check = "GOOD" if year == "2021" & new_dist == "EMPTY" & cngdstcd == manual_cd
		replace new_cd = manual_cd if manual_cd != .
		
	// Randomly sample changed districts to confirm validity
		frame put unitid instnm fips address stabbr control cngdstcd new_cd  new_dist ///
			if year == "2021" & dup_check == "BAD", into(new_dists_sample)
		
		frame change new_dists_sample
		sample 100, count
		tab stabbr 
		export excel "C:\Users\jared\Desktop\work\pnpi\data\cng_json\validity_sample.xlsx", firstrow(var) replace
		
	// Assign new cds to institutions (and apply to all previous years)
		frame change default
		gen new_cd2 = new_cd if year == "2021"
		egen new_cd3 = max(new_cd2), by(unitid)
		gen new_cd4 = new_cd3 if inlist(year,"2019","2020","2021")
		replace cngdstcd = new_cd4 if new_cd4 != . & !inlist(new_cd4,808,1100,1228,3001,3002,3714,4106,4837,4838)
		drop new_cd* manual_cd new_dist dup_check

********************************************************************************
**# [5] ADD CONG AND STATE LEVEL CENSUS ---------------------------------------|

// Merge with ACS																	// No ACS data for 2020, make note in methodology report
	merge m:1 cngdstcd year using "C:\Users\jared\Desktop\work\pnpi\data\acs\temp\acs_cd_cleaned.dta"
	drop if _merge == 2
		*CA53, IL18, MI14, NY27, OH16, PA18, TX8 (no more insts), WV3				// old CDs in 2019 and 2021; gray them out in dropdown
	drop _merge
	
	merge m:1 fips year using "C:\Users\jared\Desktop\work\pnpi\data\acs\temp\acs_state_cleaned.dta"
	drop _merge
	
	*now merge with manually tabulated census data for territories from 2020 decennial island census. Have assigned MRY manually
	*https://data.census.gov/table/DECENNIALDPAS2020.DP2?d=DECIA%20American%20Samoa%20Demographic%20Profile
	merge m:1 fips year using "C:\Users\jared\Desktop\work\pnpi\data\acs\territories_census_data_2020.dta"
		replace state = terr if terr != ""
		replace st_name = terr_name if terr_name != ""
		replace cd_name = terr_name if terr_name != ""
		replace st_pct_educ_lessthanhs = terr_pct_educ_lessthanhs if terr_pct_educ_lessthanhs != .
		replace st_pct_educ_hs = terr_pct_educ_hs if terr_pct_educ_hs != .
		replace st_pct_educ_somecoll = terr_pct_educ_somecoll if terr_pct_educ_somecoll != .
		replace st_pct_educ_assoc = terr_pct_educ_assoc if terr_pct_educ_assoc != .
		replace st_pct_educ_bach = terr_pct_educ_bach if terr_pct_educ_bach != .
		replace st_pct_educ_grad = terr_pct_educ_grad if terr_pct_educ_grad != .
	drop _merge terr_* terr
	
	gen natl_name = "United States"
	merge m:1 natl_name year using "C:\Users\jared\Desktop\work\pnpi\data\acs\temp\acs_us_cleaned.dta"
	drop _merge
	
	drop cd_tot_pop-cd_pct_pov_18up cd_unempl_rate-cd_unempl_bachplus ///
		st_tot_pop-st_pct_pov_18up st_unempl_rate-st_unempl_bachplus ///
		natl_tot_pop-natl_pct_pov_18up natl_unempl_rate-natl_unempl_bachplus		// Not using these census metrics currently
	
********************************************************************************
**# [6] GENERATE ANY NEW VARIABLES --------------------------------------------|

	drop state 
	order unitid opeid opeid2 instnm year stabbr fips cngdstcd ///
			sector control preddeg deggrant hbcu tribal pbi annhi aanapii hsi nanti
	sort fips cngdstcd unitid year

	// Combined MSI variable
		lab define binary_lab 0 "No" 1 "Yes"
		foreach x in hbcu tribal {
			recode `x' (2=0)
			lab val `x' binary_lab
		}

		gen msi = 0
		replace msi = 1 if aanapii 	== 1
		replace msi = 2 if annhi 	== 1
		replace msi = 3 if hbcu 	== 1
		replace msi = 4 if hsi 		== 1
		replace msi = 5 if nanti	== 1
		replace msi = 6 if pbi		== 1
		replace msi = 7 if tribal	== 1
		lab define msi_lab 0 "Non-MSI" 1 "AANAPII" 2 "ANNHI" 3 "HBCU" ///
			4 "HSI" 5 "NANTI" 6 "PBI" 7 "TCU"
		lab val msi msi_lab 
			
	// Create alternative sector 
		gen sector_group = 0
		replace sector_group = 1 if control == 1 & inlist(preddeg,3,4)
		replace sector_group = 2 if control == 1 & inlist(preddeg,1,2)
		replace sector_group = 3 if control == 2
		replace sector_group = 4 if control == 3
		
		lab define sect_group_lab 1 "Public 4-Year" 2 "Public 2-Year" 3 "Non-Profit" 4 "For-Profit"
		lab val sector_group sect_group_lab
		
		// Examine change from NCES sector to Scorecard PREDDEG
			preserve 
				gen sect_nces = 1 if inlist(sector,1)
				replace sect_nces = 2 if inlist(sector,4)
				replace sect_nces = 3 if inlist(sector,2,5)
				replace sect_nces = 4 if inlist(sector,3,6)
				
				tab sector_group sect_nces if year == "2021"
					*177 institutions changed classification, all from pub4 to pub2
				br instnm sector_group sect_nces control stabbr if sector_group == 2 & sect_nces == 1
					*Almost all are community colleges or technical colleges
			restore
		
	// Census Region label
		gen census_region = 0
		replace census_region = 1 if inlist(stabbr,"CT","ME","MA","NH","RI","VT")
		replace census_region = 2 if inlist(stabbr,"NJ","NY","PA")
		replace census_region = 3 if inlist(stabbr,"IN","IL","MI","OH","WI")
		replace census_region = 4 if inlist(stabbr,"IA","KS","MN","MO","NE","ND","SD")
		replace census_region = 5 if inlist(stabbr,"DE","DC","FL","GA","MD","NC","SC","VA","WV")
		replace census_region = 6 if inlist(stabbr,"AL","KY","MS","TN")
		replace census_region = 7 if inlist(stabbr,"AR","LA","OK","TX")
		replace census_region = 8 if inlist(stabbr,"AZ","CO","ID","NM","MT","UT","NV","WY")
		replace census_region = 9 if inlist(stabbr,"AK","CA","HI","OR","WA")
		
		lab define census_region_lab 	1 "New England" 2 "Middle Atlantic" ///
										3 "East North Central" 4 "West North Central" ///
										5 "South Atlantic" 6 "East South Central" ///
										7 "West South Central" 8 "Mountain" 9 "Pacific"
										
		lab val census_region census_region_lab
		
		/*
		br unitid instnm stabbr cngdstcd ug_sub_recip ef_tot_ug sector ///
			if year == "2020" & (ug_sub_recip > ef_tot_ug) & ug_sub_recip != .		// More UG DL Subsidized recips than UG enrolled?
		*/
		
	// Adjust Pell recipient amount discrepancies between FSA and IPEDS
	
		replace pell_recip = ug_pell_n if ug_pell_n > pell_recip & ug_pell_n != .	// Use whichever data source provides the most coverage of pell recipients
		replace pell_recip = ug_pell_n if ug_pell_n != . & pell_recip == .			// Use IPEDS in place of missing FSA
		replace pell_recip = ug_pell_n if (pell_recip > (ug_n))						// Use IPEDS where multiple institutions report at same FSA campus
		
	// Combine enrollment numbers								
		gen ef_tot_ug = ef_tot_ftug + ef_tot_ptug
		gen ef_tot_gr = ef_tot_ftgr + ef_tot_ptgr
		
	// Combine room, board, and other fees
		gen oncamp_rmbrdoth = oncampus_rmbrd + oncampus_other
		gen offcamp_rmbrdoth = offcampus_nfam_rmbrd + offcampus_nfam_other
		drop oncampus_rmbrd oncampus_other offcampus_nfam_rmbrd ///
			offcampus_nfam_other books_supp offcampus_fam_other
		
	// Combine grad enrollment
		foreach y in aian asian black hisp nhpi white twomore unk nra {
			gen ef_`y'_tot_gr = ef_`y'_tot_ptgr + ef_`y'_tot_ftgr
		}
		
		drop *_ptgr *_ftgr
		
	// Create trad aged enrollment 
		gen ef_trad_t_fte = ef_tot_fte - ef_nontrad_t_fte
	
	// Combine completion data by gender
		egen compr_total_men_tot = 	rowtotal(compr_total_men_assoc compr_total_men_bach ///
									compr_total_men_grad), missing
		egen compr_total_women_tot =	rowtotal(compr_total_women_assoc ///
									compr_total_women_bach compr_total_women_grad), missing
									
		egen compr_total_tot_tot = rowtotal(compr_total_men_tot compr_total_women_tot), missing

	// Create CDR3 numerator from percent
		gen cdr3_numer = (cdr3 * cdr3_denom)
		drop cdr3
	
	// Calculate numerators for weighted estimates (COA, Tuit & Fees, Net Price, RmBrd)
		// Weighted by FTE enrollment
			gen coa_numer = (coa * ef_tot_fte)
			gen indist_tuit_numer = (indist_tuit_fees * ef_tot_fte)
			gen instate_tuit_numer = (instate_tuit_fees * ef_tot_fte)
			gen outstate_tuit_numer = (outstate_tuit_fees * ef_tot_fte)
			gen oncamp_rmbrdoth_numer = (oncamp_rmbrdoth * ef_tot_fte)
			gen offcamp_rmbrdoth_numer = (offcamp_rmbrdoth * ef_tot_fte)
			drop coa indist_tuit_fees instate_tuit_fees outstate_tuit_fees ///
				oncamp_rmbrdoth offcamp_rmbrdoth
			
		// Net Price weighted by cohort family income cohort denoms
			gen netprice_tot_numer = (netprice_tot_avg * netprice_denom)
			gen netprice_less30_numer = (netprice_less30_avg * netprice_less30_denom)
			gen netprice_more110_numer = (netprice_more110_avg * netprice_more110_denom)
			drop netprice_tot_avg netprice_less30_avg netprice_more110_avg
		
********************************************************************************
**# [7] MISSINGNESS ANALYSIS --------------------------------------------------|

		*ds
		*bysort year: mdesc `r(varlist)'												// Do all years together, if wanting to log
		
		quietly ds
		mdesc `r(varlist)' if year == "2011"
			*missing msi metrics - ok
			*missing data from newer years (c15basic, scorecard repay, etc.) - ok
			*25-30% missing FSA data 
		quietly ds
		mdesc `r(varlist)' if year == "2012"
			*same as 2011, good sign
		quietly ds
		mdesc `r(varlist)' if year == "2013"
			*same as 2012
		quietly ds
		mdesc `r(varlist)' if year == "2014"
			*same as 2013
		quietly ds
		mdesc `r(varlist)' if year == "2015"
			*same, added c15basic
		quietly ds
		mdesc `r(varlist)' if year == "2016"
			*same, fewer missing in FSA (22%)
		quietly ds
		mdesc `r(varlist)' if year == "2017"
			*same
		quietly ds
		mdesc `r(varlist)' if year == "2018"
			*have repayment data now
		quietly ds
		mdesc `r(varlist)' if year == "2019"
			*same
		quietly ds
		mdesc `r(varlist)' if year == "2020"
			*same but now missing census (no ACS in 2020)
		quietly ds
		mdesc `r(varlist)' if year == "2021"
		
	// Fix st_name and cd_name from missing ACS 
		*cd_fips st_name cd_name 
		sort unitid year
		bysort unitid: carryforward st_name, replace
		bysort unitid: carryforward cd_name, replace
		bysort unitid: carryforward cd_fips, replace
		
	save "$analysis\explorer_combined.dta", replace
	export delimited "$analysis\explorer_combined.csv", replace

	
********************************************************************************
**# [8] SPLIT DATA FRAME INTO SEGMENTS FOR EACH VIEW TYPE ---------------------|

// Institution Crosswalk
	preserve 
		keep if year == "2021"
		keep unitid instnm sector_group fips cngdstcd
		save "$analysis\inst_crosswalk.dta", replace
		export delimited "$analysis\inst_crosswalk.csv", replace
	restore
	
	// Now create repeated filterable crosswalk for Tableau tooltip
	preserve 
		keep if year == "2021"
		keep unitid instnm sector_group fips
		replace fips = 0
		gen geography = "United States"
		tempfile inst_walk_nat_temp
		save `inst_walk_nat_temp'
	restore
	
	preserve
		keep if year == "2021"
		keep unitid instnm sector_group fips st_name 
		rename st_name geography
		tempfile inst_walk_st_temp
		save `inst_walk_st_temp'
	restore 
	
	preserve
		keep if year == "2021"
		keep unitid instnm sector_group cngdstcd cd_name
		rename (cngdstcd cd_name) (fips geography)
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories		
		append using `inst_walk_st_temp'
		append using `inst_walk_nat_temp'
		save "$analysis\inst_tooltip.dta", replace
		export delimited "$analysis\inst_tooltip.csv", replace
	restore
	
// Create crosswalk and tooltip for repayment report in 2018
	preserve 
		keep if year == "2018"
		keep unitid instnm sector_group fips cngdstcd
		save "$analysis\inst_crosswalk_2018.dta", replace
		export delimited "$analysis\inst_crosswalk_2018.csv", replace
	restore
	
	// Now create repeated filterable crosswalk for Tableau tooltip
	preserve 
		keep if year == "2018"
		keep unitid instnm sector_group fips
		replace fips = 0
		gen geography = "United States"
		tempfile inst_walk_nat_temp2018
		save `inst_walk_nat_temp2018'
	restore
	
	preserve
		keep if year == "2018"
		keep unitid instnm sector_group fips st_name 
		rename st_name geography
		tempfile inst_walk_st_temp2018
		save `inst_walk_st_temp2018'
	restore 
	
	preserve
		keep if year == "2018"
		keep unitid instnm sector_group cngdstcd cd_name
		rename (cngdstcd cd_name) (fips geography)
		append using `inst_walk_st_temp2018'
		append using `inst_walk_nat_temp2018'
		save "$analysis\inst_tooltip_2018.dta", replace
		export delimited "$analysis\inst_tooltip_2018.csv", replace
	restore
		

// PNPI Topline
	use "$analysis\explorer_combined.dta", clear
	
	foreach x in cdr3_numer cdr3_denom {
		gen cdr3_temp = `x' if year == "2018"								// Assign 2018 cdr to 2020 to keep it
		egen cdr3_temp2 = max(cdr3_temp), by(unitid)
		replace `x' = cdr3_temp2
		drop cdr3_temp cdr3_temp2
	}
	
	keep if year == "2021"														// keep most recent year

	keep 	instnm fips st_name cngdstcd cd_name sector_group pell_recip ///
			ef_tot_ptug ef_tot_ftug debt_mdn coa_numer cdr3_denom cdr3_numer ///
			st_pct_educ_lessthanhs st_pct_educ_hs st_pct_educ_somecoll ///
			st_pct_educ_grad st_pct_educ_assoc st_pct_educ_bach ///
			cd_pct_educ_lessthanhs cd_pct_educ_hs cd_pct_educ_somecoll ///
			cd_pct_educ_grad cd_pct_educ_assoc cd_pct_educ_bach ///
			natl_pct_educ_lessthanhs natl_pct_educ_hs natl_pct_educ_somecoll ///
			natl_pct_educ_grad natl_pct_educ_assoc natl_pct_educ_bach ///
			ef_tot_fte ef_aian_tot_fte ef_asian_tot_fte ef_black_tot_fte ///
			ef_hisp_tot_fte ef_nhpi_tot_fte ef_white_tot_fte ///
			ef_twomore_tot_fte ef_unk_tot_fte ef_nra_tot_fte ///
			gr_total_tot denom150 ug_n
			
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds pell_recip ef_* ug_n														// sum at geog level
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level') missing
			}
			
			ds gr_total_tot denom150 coa_numer ef_tot_fte cdr3*
			foreach y in `r(varlist)' {
				egen `x'_se_`y' = sum(`y'), by(sector_group `level') missing		// sum at geog level & sector
			}
			
			ds debt_mdn																// median at geog level & sector
			foreach y in `r(varlist)' {
				egen `x'_m_`y' = median(`y'), by(sector_group `level')
			}
			
			gen `x'_pt_pell = 	(`x'_s_pell_recip) / ///							// pcts at geog level
								(`x'_s_ug_n)
			drop `x'_s_ug_n
								
			rename `x'_s_ef_tot_fte `x'_tot_fte										// So they don't get picked up in loop
			
			ds `x'_s_ef_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_fte
			}
			
			gen `x'_a_gr_total_tot_150 = (`x'_se_gr_total_tot / `x'_se_denom150)	// Grad rates calced at geog and sector
			gen `x'_a_coa = (`x'_se_coa_numer / `x'_se_ef_tot_fte)					// Weighted COA average
			gen `x'_a_cdr3 = (`x'_se_cdr3_numer / `x'_se_cdr3_denom)				// CDR3 calced at geog and sector
		}
			
	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name sector_group nat_* pt_nat_* natl_*
				replace fips = 0
				replace st_name = "United States"
				rename st_name geography
				duplicates drop fips sector_group, force
				rename nat_* *
				rename natl_* *
				rename pt_nat_* pt_*
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name sector_group st_* pt_st_*
				rename st_name geography
				duplicates drop fips sector_group, force
				rename st_* *
				rename pt_st_* pt_*
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name sector_group cd_* pt_cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips sector_group, force
				rename cd_* *
				rename pt_cd_* pt_*
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		drop se_gr_total_tot se_denom150 se_coa_numer se_cdr3_denom ///
			se_cdr3_numer se_ef_tot_fte
			
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
		
		// Check for missing metrics (for all sectors)
			preserve 
				ds																	// All vars in array
				mdesc `r(varlist)'													// Identify missing obs
				di "`r(miss_vars)'"
				foreach x in `r(miss_vars)' {
					egen max_`x' = max(`x'), by(geography)							// Will reveal if missing for all sectors 
				}
				mdesc max*															// get vars missing all sectors
				foreach x in `r(miss_vars)' {
					di "Geographies that are missing all observations for `x'"
					list geography sector_group `x' if `x' == .						// List geogs missing all sectors and for which vars
				}
			restore
			
	// Add in the new CDs from 2020 with no data for mapping purposes 
		frame create newdists_2020
		frame change newdists_2020 
		set obs 9
		gen fips = .
		replace fips = 808 if _n == 1
		replace fips = 1228 if _n == 2
		replace fips = 3001 if _n == 3
		replace fips = 3002 if _n == 4
		replace fips = 3714 if _n == 5
		replace fips = 4106 if _n == 6
		replace fips = 4837 if _n == 7
		replace fips = 4838 if _n == 8
		replace fips = 4808 if _n == 9
		
		gen geography = ""
		replace geography = "Congressional District 8, Colorado" if _n == 1
		replace geography = "Congressional District 28, Florida" if _n == 2
		replace geography = "Congressional District 1, Montana" if _n == 3
		replace geography = "Congressional District 2, Montana" if _n == 4
		replace geography = "Congressional District 14, North Carolina" if _n == 5
		replace geography = "Congressional District 6, Oregon" if _n == 6
		replace geography = "Congressional District 37, Texas" if _n == 7
		replace geography = "Congressional District 38, Texas" if _n == 8
		replace geography = "Congressional District 8, Texas" if _n == 9
		
		gen st_fips = .
		replace st_fips = 8 if _n == 1
		replace st_fips = 12 if _n == 2
		replace st_fips = 30 if _n == 3
		replace st_fips = 30 if _n == 4
		replace st_fips = 37 if _n == 5
		replace st_fips = 41 if _n == 6
		replace st_fips = 48 if _n == 7
		replace st_fips = 48 if _n == 8
		replace st_fips = 48 if _n == 9
		
		gen st_name = ""
		replace st_name = "Colorado" if _n == 1
		replace st_name = "Florida" if _n == 2
		replace st_name = "Montana" if _n == 3
		replace st_name = "Montana" if _n == 4
		replace st_name = "North Carolina" if _n == 5
		replace st_name = "Oregon" if _n == 6
		replace st_name = "Texas" if _n == 7
		replace st_name = "Texas" if _n == 8
		replace st_name = "Texas" if _n == 9
		
		frame change default
		frameappend newdists_2020
		
		sort fips sector_group
			
	save "$analysis\explorer_topline.dta", replace
	export delimited "$analysis\explorer_topline.csv", replace
	
// Student Debt
	use "$analysis\explorer_combined.dta", clear
	
	keep if year == "2021"														// keep most recent year

	keep 	instnm fips st_name cngdstcd cd_name sector_group grad_debt_mdn ///
			wdraw_debt_mdn debt_mdn hi_inc_debt_mdn ///
			lo_inc_debt_mdn ef_tot_ftug ef_tot_ptug pplus_recip ef_tot_gr ///
			ef_tot_fte gplus_recip ug_sub_recip ug_unsub_recip ///
			gr_unsub_recip lpstafford_cnt lpstafford_amt lppplus_cnt lppplus_amt
			
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds ug_sub_recip ug_unsub_recip gr_unsub_recip pplus_recip ///
				gplus_recip ef_* lp*												// sum at geog level
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(sector_group `level') missing
			}
			
			drop 	`x'_s_ug_sub_recip `x'_s_ug_unsub_recip ///
					`x'_s_gr_unsub_recip `x'_s_ef_tot_fte
			
			egen `x'_s_ug_sub_recip = sum(ug_sub_recip), by(`level') missing		// Make totals irrespective of sector
			egen `x'_s_ug_unsub_recip = sum(ug_unsub_recip), by(`level') missing
			egen `x'_s_gr_unsub_recip = sum(gr_unsub_recip), by(`level') missing
			
			ds ef_* 
			foreach y in `r(varlist)' {
				egen `x'_stot_`y' = sum(`y'), by(`level') missing
			}
			
			ds grad_debt_mdn wdraw_debt_mdn debt_mdn ///
				hi_inc_debt_mdn lo_inc_debt_mdn										// median at geog level & sector
			foreach y in `r(varlist)' {
				egen `x'_m_`y' = median(`y'), by(sector_group `level')
			}
			
			
			ds ug_sub_recip ug_unsub_recip											// pcts at geog level
			foreach y in `r(varlist)' {
				gen `x'_pt_`y' = 	(`x'_s_`y') / ///
									(`x'_stot_ef_tot_ftug + `x'_stot_ef_tot_ptug)
			}
			
			gen `x'_pt_pplus_recip = 	(`x'_s_pplus_recip) / ///
										(`x'_s_ef_tot_ftug + `x'_s_ef_tot_ptug)
								
			gen `x'_pt_gr_unsub_recip = 	(`x'_s_gr_unsub_recip) / ///			// now for grad amounts
											(`x'_stot_ef_tot_gr)
			
			gen `x'_pt_gplus_recip = 	(`x'_s_gplus_recip) / ///
										(`x'_s_ef_tot_gr)
			
			
			gen `x'_a_dl = `x'_s_lpstafford_amt / `x'_s_lpstafford_cnt				// average at geog level & sector AFTER summing
			gen `x'_a_pplus = `x'_s_lppplus_amt / `x'_s_lppplus_cnt
		
		}

	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name sector_group nat_*
				replace fips = 0
				replace st_name = "United States"
				rename st_name geography
				duplicates drop fips sector_group, force
				rename nat_* *
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name sector_group st_*
				rename st_name geography
				duplicates drop fips sector_group, force
				rename st_* *
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name sector_group cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips sector_group, force
				rename cd_* *
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
			
		// Check for missing metrics (for all sectors)
			preserve 
				ds																	// All vars in array
				mdesc `r(varlist)'													// Identify missing obs
				foreach x in `r(miss_vars)' {
					egen max_`x' = max(`x'), by(geography)							// Will reveal if missing for all sectors 
				}
				mdesc max*															// get vars missing all sectors
				foreach x in `r(miss_vars)' {
					di "Geographies that are missing all observations for `x'"
					list geography sector_group `x' if `x' == .						// List geogs missing all sectors and for which vars
				}
			restore
			
	frameappend newdists_2020
	sort fips sector_group
			
	save "$analysis\explorer_debt.dta", replace
	export delimited "$analysis\explorer_debt.csv", replace
			
// Enroll & Access
	use "$analysis\explorer_combined.dta", clear									
	
	keep if year == "2021"															// keep most recent year

	keep 	instnm fips st_name cngdstcd cd_name sector_group pell_recip ///
			ef_tot_f* ef_tot_p* ef_*_tot_f* ef_*_tot_p* dist_denom ///
			dist_excl dist_some dist_none ef_tot_men_fte ef_tot_women_fte ///
			ef_nontrad_t_fte ef_trad_t_fte ef_tot_ug ef_tot_gr ef_*_tot_gr ///
			ug_n
			
	drop ef_*_tot_fte
			
	// Create pell recip duplicate for sector breakdown
		gen pell_recip2 = pell_recip
		gen ug_n2 = ug_n
	
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds pell_recip ef_*_ftug ef_*_ptug ef_*_gr ug_n							// sum at geog level
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level') missing
			}
			
			ds ef_*_fte dist_*														// sum at geog level & sector
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(sector_group `level') missing
			}
			
			ds pell_recip2 ef_tot_ug ug_n2											// re-calc pell recips by sector
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(sector_group `level') missing
			}
			
			gen `x'_pt_pell = 	(`x'_s_pell_recip) / ///							// pcts at geog level
								(`x'_s_ug_n)
			drop `x'_s_ug_n
			
			gen `x'_pt_pell_sect = 	(`x'_s_pell_recip2) / ///
									(`x'_s_ug_n2)
			drop `x'_s_ug_n2
								
			rename 	(`x'_s_ef_tot_fte `x'_s_ef_tot_gr `x'_s_ef_tot_ftug `x'_s_ef_tot_ptug) ///
					(`x'_tot_fte `x'_tot_gr `x'_tot_ftug `x'_tot_ptug)				// So they don't get picked up in loop
			
			ds `x'_s_ef_*_gr
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_gr
			}
			
			ds `x'_s_ef_*_ftug
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_ftug
			}
	
			ds `x'_s_ef_*_ptug
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_ptug
			}

			ds `x'_s_ef_tot_men_fte `x'_s_ef_tot_women_fte ///
				`x'_s_ef_nontrad_t_fte `x'_s_ef_trad_t_fte
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_fte
			}
			
			ds `x'_s_dist_excl `x'_s_dist_some `x'_s_dist_none
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_dist_denom
			}
		}
			
	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name sector_group nat_* pt_nat_*
				replace fips = 0
				replace st_name = "United States"
				rename st_name geography
				duplicates drop fips sector_group, force
				rename nat_* *
				rename pt_nat_* pt_*
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name sector_group st_* pt_st_*
				rename st_name geography
				duplicates drop fips sector_group, force
				rename st_* *
				rename pt_st_* pt_*
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name sector_group cd_* pt_cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips sector_group, force
				rename cd_* *
				rename pt_cd_* pt_*
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
			
		// Check for missing metrics (for all sectors)
			preserve 
				ds																	// All vars in array
				mdesc `r(varlist)'													// Identify missing obs
				foreach x in `r(miss_vars)' {
					egen max_`x' = max(`x'), by(geography)							// Will reveal if missing for all sectors 
				}
				mdesc max*															// get vars missing all sectors
				foreach x in `r(miss_vars)' {
					di "Geographies that are missing all observations for `x'"
					list geography sector_group `x' if `x' == .						// List geogs missing all sectors and for which vars
				}
			restore
			
	frameappend newdists_2020
	sort fips sector_group 
			
	save "$analysis\explorer_enroll.dta", replace
	export delimited "$analysis\explorer_enroll.csv", replace
	
			
// College Cost
	use "$analysis\explorer_combined.dta", clear
	
	keep if year == "2021"														// keep most recent year

	keep 	instnm fips st_name cngdstcd cd_name sector_group indist_tuit_numer ///
			instate_tuit_numer outstate_tuit_numer oncamp_rmbrdoth_numer ///
			offcamp_rmbrdoth_numer ef_tot_fte tot_inst_aid ///
			gross_tuition_rev tot_inst_aid netprice_tot_numer netprice_less30_numer ///
			netprice_more110_numer state_approp coa_numer netprice_denom ///
			netprice_less30_denom netprice_more110_denom
			
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds ef_tot_fte tot_inst_aid gross_tuition_rev netprice* ///
				oncamp_rmbrdoth_numer offcamp_rmbrdoth_numer coa_numer				// sum at geog level & sector
			foreach y in `r(varlist)' {
				egen `x'_sect_`y' = sum(`y'), by(sector_group `level') missing
			}
			
			ds indist_tuit_numer ef_tot_fte ///
				instate_tuit_numer outstate_tuit_numer								// sum at geog level
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level') missing
			}
			
			ds ef_tot_fte state_approp												// Only calc for public institutions
			foreach y in `r(varlist)' {
				egen `x'_spub1_`y' = sum(`y') if inlist(sector_group,1,2), by(`level') missing
				egen `x'_spub_`y' = max(`x'_spub1_`y'), by(`level')
				drop `x'_spub1_`y'
			}
			
			gen `x'_st_approp_fte = 	`x'_spub_state_approp / `x'_spub_ef_tot_fte		// State approp per fte
			gen `x'_inst_aid_fte = 	`x'_sect_tot_inst_aid / `x'_sect_ef_tot_fte		// Inst aid per fte
			gen `x'_a_tuit_discount_rt = `x'_sect_tot_inst_aid / `x'_sect_gross_tuition_rev
			gen `x'_a_indist_tuit_fees = `x'_s_indist_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_instate_tuit_fees = `x'_s_instate_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_outstate_tuit_fees = `x'_s_outstate_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_netprice_tot_avg = `x'_sect_netprice_tot_numer / `x'_sect_netprice_denom
			gen `x'_a_netprice_less30_avg = `x'_sect_netprice_less30_numer / `x'_sect_netprice_less30_denom
			gen `x'_a_netprice_more110_avg = `x'_sect_netprice_more110_numer / `x'_sect_netprice_more110_denom
			gen `x'_a_oncamp_rmbrdoth = `x'_sect_oncamp_rmbrdoth_numer / `x'_sect_ef_tot_fte
			gen `x'_a_offcamp_rmbrdoth = `x'_sect_offcamp_rmbrdoth_numer / `x'_sect_ef_tot_fte
			gen `x'_a_coa = `x'_sect_coa_numer / `x'_sect_ef_tot_fte
		}

	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name sector_group nat_* 
				replace fips = 0
				replace st_name = "United States"
				rename st_name geography
				duplicates drop fips sector_group, force
				rename nat_* *
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name sector_group st_*
				rename st_name geography
				duplicates drop fips sector_group, force
				rename st_* *
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name sector_group cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips sector_group, force
				rename cd_* *
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		drop sect_* spub_state_approp spub_ef_tot_fte
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
		
		// Check for missing metrics (for all sectors)
			preserve 
				ds																	// All vars in array
				mdesc `r(varlist)'													// Identify missing obs
				foreach x in `r(miss_vars)' {
					egen max_`x' = max(`x'), by(geography)							// Will reveal if missing for all sectors 
				}
				mdesc max*															// get vars missing all sectors
				foreach x in `r(miss_vars)' {
					di "Geographies that are missing all observations for `x'"
					list geography sector_group `x' if `x' == .						// List geogs missing all sectors and for which vars
				}
			restore
			
	frameappend newdists_2020
	sort fips sector_group
			
	save "$analysis\explorer_cost.dta", replace
	export delimited "$analysis\explorer_cost.csv", replace
			
// Completion & Attainment
	use "$analysis\explorer_combined.dta", clear
	
	keep if year == "2021"															// keep most recent year

	keep 	instnm fips st_name cngdstcd cd_name sector_group ///
			st_pct_educ_lessthanhs st_pct_educ_hs st_pct_educ_somecoll ///
			st_pct_educ_grad st_pct_educ_assoc st_pct_educ_bach ///
			cd_pct_educ_lessthanhs cd_pct_educ_hs cd_pct_educ_somecoll ///
			cd_pct_educ_grad cd_pct_educ_assoc cd_pct_educ_bach ///
			natl_pct_educ_lessthanhs natl_pct_educ_hs natl_pct_educ_somecoll ///
			natl_pct_educ_grad natl_pct_educ_assoc natl_pct_educ_bach ///
			compr_*_tot_* compr_total_men_* gr_total_tot denom150 ///
			compr_total_women_* ef_tot_fte
											
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds compr_total_tot_* compr_total_men_tot compr_total_women_tot ///
				gr_total_tot denom150 												// sum at geog level & sector
			foreach y in `r(varlist)' {
				egen `x'_se_`y' = sum(`y'), by(sector_group `level') missing
			}
			
			ds compr_*_tot_* ef_tot_fte												// sum at geog level
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level') missing
			}		
								
			foreach y in assoc bach grad {
				rename `x'_s_compr_total_tot_`y' `x'_tot_`y'						// Prevent from getting picked up in loop
			}
			
			ds `x'_s_compr_*_assoc
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_assoc
			}
			
			ds `x'_s_compr_*_bach
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_bach
			}
			
			ds `x'_s_compr_*_grad
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_tot_grad
			}
			
			ds `x'_se_compr_total_men_tot `x'_se_compr_total_women_tot
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_se_compr_total_tot_tot
			}
			
			gen `x'_a_gr_total_tot_150 = (`x'_se_gr_total_tot / `x'_se_denom150)	// Grad rates calced at geog and sector
		}

	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name sector_group nat_* natl_* pt_nat_*
				replace fips = 0
				replace st_name = "United States"
				rename st_name geography
				duplicates drop fips sector_group, force
				rename nat_* *
				rename natl_* *
				rename pt_nat_* pt_*
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name sector_group st_* pt_st_*
				rename st_name geography
				duplicates drop fips sector_group, force
				rename st_* *
				rename pt_st_* pt_*
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name sector_group cd_* pt_cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips sector_group, force
				rename cd_* *
				rename pt_cd_* pt_*
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
			
		// Check for missing metrics (for all sectors)
			preserve 
				ds																	// All vars in array
				mdesc `r(varlist)'													// Identify missing obs
				foreach x in `r(miss_vars)' {
					egen max_`x' = max(`x'), by(geography)							// Will reveal if missing for all sectors 
				}
				mdesc max*															// get vars missing all sectors
				foreach x in `r(miss_vars)' {
					di "Geographies that are missing all observations for `x'"
					list geography sector_group `x' if `x' == .						// List geogs missing all sectors and for which vars
				}
			restore
			
	frameappend newdists_2020
	sort fips sector_group
			
	save "$analysis\explorer_complete.dta", replace
	export delimited "$analysis\explorer_complete.csv", replace
			
// Repayment
	use "$analysis\explorer_combined.dta", clear
	
	keep if year == "2018"															// keep most recent year for repayment data

	keep 	instnm fips st_name cngdstcd cd_name sector_group ///
			bbrr2_fed_ug_* bbrr2_fed_ugnocomp_* bbrr2_fed_gr_n ///
			bbrr2_pp_ug_* cdr3_numer cdr3_denom
			
	renvars *_paidinfull, subst(paidinfull pif)										// shorten var names
	renvars *_discharge, subst(discharge disch)
	renvars *_ugnocomp_*, subst(ugnocomp ugnc)
			
	/*
	ds bbrr2*
	foreach x in `r(varlist)' {
		recode `x' (.=0)
	}
	*/
	
	// Temporarily rename totals for loop purpose 
		rename 	(bbrr2_fed_ug_n bbrr2_fed_ugnc_n bbrr2_pp_ug_n) ///
				(fed_ug_n fed_ugnc_n pp_ug_n)
				
	// Create totals from %s so we can calc % aggregates
		ds bbrr2_fed_ug_* 
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * fed_ug_n
		}
		
		ds bbrr2_fed_ugnc_*
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * fed_ugnc_n
		}
		
		ds bbrr2_pp_ug_*
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * pp_ug_n
		}
		
	keep 	instnm fips st_name cngdstcd cd_name sector_group ///
			bbrr2_fed_ug_*_1 bbrr2_fed_ugnc_*_1 bbrr2_fed_gr_n ///
			bbrr2_pp_ug_*_1 cdr3_numer cdr3_denom fed_ug_n fed_ugnc_n pp_ug_n
			
	rename bbrr2_* *																// shorten var names
	
	drop if sector_group == 0 														// UW Colleges consolidated this year, dropped from data
								
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds fed_ug_*_1 fed_ugnc_*_1 fed_ug_n fed_ugnc_n cdr3*					// sum at geog level & sector
			foreach y in `r(varlist)' {
				egen `x'_se_`y' = sum(`y'), by(sector_group `level') missing
			}
			
			ds fed_gr_n pp_ug_n pp_ug_*_1 fed_ug_n									// sum at geog level
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level') missing
			}		
			
			ds `x'_se_fed_ug_*_1
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_se_fed_ug_n
			}
			
			ds `x'_se_fed_ugnc_*_1 
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_se_fed_ugnc_n
			}
			
			ds `x'_s_pp_ug_*_1
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_pp_ug_n
			}
			
			gen `x'_a_cdr3 = `x'_se_cdr3_numer / `x'_se_cdr3_denom
			
			drop `x'_se_cdr3_numer `x'_se_cdr3_denom
		}

	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name sector_group nat_* pt_nat_*
				replace fips = 0
				replace st_name = "United States"
				rename st_name geography
				duplicates drop fips sector_group, force
				rename nat_* *
				rename pt_nat_* pt_*
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name sector_group st_* pt_st_*
				rename st_name geography
				duplicates drop fips sector_group, force
				rename st_* *
				rename pt_st_* pt_*
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name sector_group cd_* pt_cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips sector_group, force
				rename cd_* *
				rename pt_cd_* pt_*
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
	rename pt_*_1 pt_*
	drop *_1
	
		drop if inlist(fips,6098,6698,6998,7298,7898)								// Remove duplicates for CDs in territories
		
	
		// Check for missing metrics (for all sectors)
			preserve 
				ds																	// All vars in array
				mdesc `r(varlist)'													// Identify missing obs
				foreach x in `r(miss_vars)' {
					egen max_`x' = max(`x'), by(geography)							// Will reveal if missing for all sectors 
				}
				mdesc max*															// get vars missing all sectors
				foreach x in `r(miss_vars)' {
					di "Geographies that are missing all observations for `x'"
					list geography sector_group `x' if `x' == .						// List geogs missing all sectors and for which vars
				}
			restore
			
	frameappend newdists_2020
	sort fips sector_group
			
	save "$analysis\explorer_repay.dta", replace
	export delimited "$analysis\explorer_repay.csv", replace
			
// Custom Report																	// Just include all vars in other reports for now
	use "$analysis\explorer_combined.dta", clear
	ds 	bbrr2_fed_ug_* bbrr2_fed_ugnocomp_* bbrr2_fed_gr_n ///
		bbrr2_pp_ug_* cdr3_numer cdr3_denom
	
	foreach x in `r(varlist)' {
		gen `x'_t = `x' if year == "2018"											// Assign 2018 to 2020 for all repayment/default metrics (to keep)
		egen `x'_t2 = max(`x'_t), by(unitid)
		replace `x' = `x'_t2
		drop `x'_t `x'_t2
	}
		
	keep if year == "2021"															// keep most recent year (and others I changed above)

	keep 	unitid instnm fips st_name cngdstcd cd_name sector_group pell_recip ///
			debt_mdn coa_numer cdr3_numer cdr3_denom st_pct_educ_lessthanhs ///
			st_pct_educ_hs st_pct_educ_somecoll st_pct_educ_grad ///
			st_pct_educ_assoc st_pct_educ_bach cd_pct_educ_lessthanhs ///
			cd_pct_educ_hs cd_pct_educ_somecoll cd_pct_educ_grad ///
			cd_pct_educ_assoc cd_pct_educ_bach natl_pct_educ_lessthanhs ///
			natl_pct_educ_hs natl_pct_educ_somecoll natl_pct_educ_grad ///
			natl_pct_educ_assoc natl_pct_educ_bach ef_tot_fte ///
			ef_aian_tot_fte ef_asian_tot_fte ef_black_tot_fte ///
			ef_hisp_tot_fte ef_nhpi_tot_fte ef_white_tot_fte ///
			ef_twomore_tot_fte ef_unk_tot_fte ef_nra_tot_fte ///
			grad_debt_mdn wdraw_debt_mdn hi_inc_debt_mdn ///
			lo_inc_debt_mdn ef_tot_ftug ef_tot_ptug pplus_recip ///
			ef_tot_fte gplus_recip ug_sub_recip ug_unsub_recip ///
			gr_unsub_recip lpstafford_cnt lpstafford_amt lppplus_cnt lppplus_amt ///
			ef_tot_f* ef_tot_p* ef_*_tot_f* ef_*_tot_p* ef_tot_gr ef_*_tot_gr dist_denom ///
			dist_excl dist_some dist_none ef_tot_men_fte ef_tot_women_fte ///
			ef_nontrad_t_fte ef_trad_t_fte ef_tot_ug indist_tuit_numer ///
			instate_tuit_numer outstate_tuit_numer oncamp_rmbrdoth_numer ///
			offcamp_rmbrdoth_numer ef_tot_fte tot_inst_aid ///
			gross_tuition_rev netprice_denom netprice_less30_denom ///
			netprice_more110_denom netprice_tot_numer netprice_less30_numer ///
			netprice_more110_numer state_approp compr_*_tot_* compr_total_men_* ///
			compr_total_women_*	bbrr2_fed_ug_* bbrr2_fed_ugnocomp_* bbrr2_fed_gr_n ///
			bbrr2_pp_ug_* gr_total_tot denom150 ug_n
			
	renvars *_paidinfull, subst(paidinfull pif)										// shorten var names of repayment rates
	renvars *_discharge, subst(discharge disch)
	renvars *_ugnocomp_*, subst(ugnocomp ugnc)
	renvars *_makeprog, subst(makeprog mkprg)
			
	/*
	ds bbrr2*
	foreach x in `r(varlist)' {														// recode repayment rates for calc
		recode `x' (.=0)
	}
	*/
	
	// Temporarily rename totals for loop purpose 
		rename 	(bbrr2_fed_ug_n bbrr2_fed_ugnc_n bbrr2_pp_ug_n) ///
				(fed_ug_n fed_ugnc_n pp_ug_n)
				
	// Create totals from %s so we can calc % aggregates
		ds bbrr2_fed_ug_* 
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * fed_ug_n
		}
		
		ds bbrr2_fed_ugnc_*
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * fed_ugnc_n
		}
		
		ds bbrr2_pp_ug_*
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * pp_ug_n
		}
					
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds 	ef_* dist_* compr_* tot_inst_aid lp* ///				// sum at geog level and sector
				ug_sub_recip ug_unsub_recip gr_unsub_recip pplus_recip ///
				gplus_recip pell_recip fed_ug_n fed_ugnc_n ///
				pp_ug_n bbrr2_*_1 gr_total_tot denom150 gross_tuition_rev ///
				indist_tuit_numer instate_tuit_numer outstate_tuit_numer ///
				oncamp_rmbrdoth_numer offcamp_rmbrdoth_numer coa_numer ///
				cdr3_numer cdr3_denom netprice_denom netprice_less30_denom ///
				netprice_more110_denom netprice_tot_numer netprice_less30_numer ///
				netprice_more110_numer ug_n
			foreach y in `r(varlist)' {
				egen `x'_t_`y' = sum(`y'), by(`level') missing
				egen `x'_s_`y' = sum(`y'), by(`level' sector_group) missing
			}	
			
			ds ef_tot_fte state_approp
			foreach y in `r(varlist)' {
				egen `x'_tpub1_`y' = sum(`y') if inlist(sector_group,1,2), by(`level') missing
				egen `x'_tpub_`y' = max(`x'_tpub1_`y'), by(`level')
				egen `x'_spub1_`y' = sum(`y') if inlist(sector_group,1,2), by(`level' sector_group) missing
				egen `x'_spub_`y' = max(`x'_spub1_`y'), by(`level' sector_group)			
			}	
			
			ds 	debt_mdn grad_debt_mdn wdraw_debt_mdn lo_inc_debt_mdn ///			// median at geog level
				hi_inc_debt_mdn
			foreach y in `r(varlist)' {
				egen `x'_t_`y' = median(`y'), by(`level')
				egen `x'_s_`y' = median(`y'), by(`level' sector_group)
			}
		
			ds `x'_s_ef_*_tot_ftug
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_ftug
			}
			
				ds `x'_t_ef_*_tot_ftug
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_ef_tot_ftug
				}
			
			ds `x'_s_ef_*_tot_fte `x'_s_ef_tot_men_fte `x'_s_ef_tot_women_fte ///
				`x'_s_ef_nontrad_t_fte `x'_s_ef_trad_t_fte
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_fte
			}
			
				ds `x'_t_ef_*_tot_fte `x'_t_ef_tot_men_fte `x'_t_ef_tot_women_fte ///
					`x'_t_ef_nontrad_t_fte `x'_t_ef_trad_t_fte
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_ef_tot_fte
				}
			
			ds `x'_s_ef_*_tot_gr
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_gr
			}
			
				ds `x'_t_ef_*_tot_gr
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_ef_tot_gr
				}

			ds `x'_s_bbrr2_fed_ug_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_fed_ug_n
			}
			
				ds `x'_t_bbrr2_fed_ug_*
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_fed_ug_n
				}
			
			ds `x'_s_bbrr2_fed_ugnc_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_fed_ugnc_n
			}
			
				ds `x'_t_bbrr2_fed_ugnc_*
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_fed_ugnc_n
				}
			
			ds `x'_s_bbrr2_pp_ug_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_pp_ug_n
			}
			
				ds `x'_t_bbrr2_pp_ug_*
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_pp_ug_n
				}
			
			rename `x'_s_dist_denom `x'_s_distance_denom
			rename `x'_t_dist_denom `x'_t_distance_denom

			ds `x'_s_dist_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_distance_denom
			}
			
				ds `x'_t_dist_*
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_distance_denom
				}
			
			rename (`x'_s_compr_total_tot_assoc `x'_s_compr_total_tot_bach ///
					`x'_s_compr_total_tot_grad `x'_s_compr_total_tot_tot) ///
					(`x'_s_compr_total_assoc `x'_s_compr_total_bach `x'_s_compr_total_grad ///
					`x'_s_compr_total)
					
			ds 	`x'_s_compr_*_tot_assoc
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_assoc
			}
			
			ds `x'_s_compr_*_tot_bach
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_bach
			}
			
			ds `x'_s_compr_*_tot_grad
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_grad
			}
			
			ds `x'_s_compr_total_men_tot `x'_s_compr_total_women_tot
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total
			}
			
				rename (`x'_t_compr_total_tot_assoc `x'_t_compr_total_tot_bach ///
						`x'_t_compr_total_tot_grad `x'_t_compr_total_tot_tot) ///
						(`x'_t_compr_total_assoc `x'_t_compr_total_bach `x'_t_compr_total_grad ///
						`x'_t_compr_total)
						
				ds 	`x'_t_compr_*_tot_assoc
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_compr_total_assoc
				}
				
				ds `x'_t_compr_*_tot_bach
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_compr_total_bach
				}
				
				ds `x'_t_compr_*_tot_grad
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_compr_total_grad
				}
				
				ds `x'_t_compr_total_men_tot `x'_t_compr_total_women_tot
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_compr_total
				}

			ds 	`x'_s_ug_sub_recip `x'_s_ug_unsub_recip `x'_s_pplus_recip 
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_ug
			}
			
				ds 	`x'_t_ug_sub_recip `x'_t_ug_unsub_recip `x'_t_pplus_recip
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_ef_tot_ug
				}
				
			ds 	`x'_s_pell_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ug_n
			}
			
				ds 	`x'_t_pell_recip
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_ug_n
				}
				
				drop `x'_s_ug_n `x'_t_ug_n
			
			ds `x'_s_gr_unsub_recip `x'_s_gplus_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_gr
			}
			
				ds `x'_t_gr_unsub_recip `x'_t_gplus_recip
				foreach y in `r(varlist)' {
					gen pt_`y' = `y' / `x'_t_ef_tot_gr
				}
			
			gen `x'_s_tot_inst_aid_fte = `x'_s_tot_inst_aid / `x'_s_ef_tot_fte
			gen `x'_s_st_approp_fte = `x'_spub_state_approp / `x'_spub_ef_tot_fte
			
				gen `x'_t_st_approp_fte = `x'_tpub_state_approp / `x'_tpub_ef_tot_fte
				gen `x'_t_tot_inst_aid_fte = `x'_t_tot_inst_aid / `x'_t_ef_tot_fte
				drop `x'_tpub_state_approp `x'_tpub_ef_tot_fte `x'_t_tot_inst_aid ///
					`x'_spub_state_approp `x'_spub_ef_tot_fte
		
			gen `x'_s_lpstafford_avg = `x'_s_lpstafford_amt / `x'_s_lpstafford_cnt
			gen `x'_s_lppplus_avg = `x'_s_lppplus_amt / `x'_s_lppplus_cnt
			drop `x'_s_lpstafford_amt `x'_s_lpstafford_cnt `x'_s_lppplus_amt `x'_s_lppplus_cnt
			
				gen `x'_t_lpstafford_avg = `x'_t_lpstafford_amt / `x'_t_lpstafford_cnt
				gen `x'_t_lppplus_avg = `x'_t_lppplus_amt / `x'_t_lppplus_cnt
				drop `x'_t_lpstafford_amt `x'_t_lpstafford_cnt `x'_t_lppplus_amt `x'_t_lppplus_cnt
				
			gen `x'_s_gr_total_tot_150 = `x'_s_gr_total_tot / `x'_s_denom150
			drop `x'_s_gr_total_tot `x'_s_denom150 `x'_t_gr_total_tot `x'_t_denom150
			
			gen `x'_s_tuit_discount_rt = `x'_s_tot_inst_aid / `x'_s_gross_tuition_rev
			drop `x'_s_tot_inst_aid `x'_s_gross_tuition_rev `x'_t_gross_tuition_rev
			
			gen `x'_t_indist_tuit_fees = `x'_t_indist_tuit_numer / `x'_t_ef_tot_fte
			gen `x'_t_instate_tuit_fees = `x'_t_instate_tuit_numer / `x'_t_ef_tot_fte
			gen `x'_t_outstate_tuit_fees = `x'_t_outstate_tuit_numer / `x'_t_ef_tot_fte
			
			gen `x'_s_coa = `x'_s_coa_numer / `x'_s_ef_tot_fte
			gen `x'_s_oncamp_rmbrdoth = `x'_s_oncamp_rmbrdoth_numer / `x'_s_ef_tot_fte
			gen `x'_s_offcamp_rmbrdoth = `x'_s_offcamp_rmbrdoth_numer / `x'_s_ef_tot_fte
			gen `x'_s_cdr3 = `x'_s_cdr3_numer / `x'_s_cdr3_denom
			gen `x'_s_netprice_tot_avg = `x'_s_netprice_tot_numer / `x'_s_netprice_denom
			gen `x'_s_netprice_less30_avg = `x'_s_netprice_less30_numer / `x'_s_netprice_less30_denom
			gen `x'_s_netprice_more110_avg = `x'_s_netprice_more110_numer / `x'_s_netprice_more110_denom
			drop `x'_s_coa_numer `x'_s_oncamp_rmbrdoth_numer ///
				`x'_s_offcamp_rmbrdoth_numer `x'_s_cdr3_numer `x'_s_cdr3_denom ///
				`x'_s_netprice_tot_numer `x'_s_netprice_denom `x'_s_netprice_less30_numer ///
				`x'_s_netprice_less30_denom `x'_s_netprice_more110_numer ///
				`x'_s_netprice_more110_denom
			
		}

	//lab define msi_lab 8 "All", add
	lab define sect_group_lab 5 "All", add
		
	// Split and append to make long form
		// Total estimates
			// National 
				preserve 
					keep fips st_name sector_group nat_* pt_nat_* natl_*
					replace fips = 0
					replace st_name = "United States"
					rename st_name geography
					rename natl_* *
					rename nat_* *
					rename pt_nat_* pt_*
					keep fips geography sector_group t_* pt_t_* pct_educ_*
					rename t_* s_*
					rename pt_t_* pt_s_*
					replace sector_group = 5
					duplicates drop fips, force
					tempfile combined_nat_temp1
					save `combined_nat_temp1'
				restore

			// State
				preserve 
					keep fips st_name sector_group st_* pt_st_*
					rename st_name geography
					rename st_* *
					rename pt_st_* pt_*
					keep fips geography sector_group t_* pt_t_* pct_educ_*
					rename t_* s_*
					rename pt_t_* pt_s_*
					replace sector_group = 5
					duplicates drop fips, force
					tempfile combined_st_temp1
					save `combined_st_temp1'	
				restore 
				
			// CDs
				preserve 
					keep fips st_name cngdstcd cd_name sector_group cd_* pt_cd_*
					rename cd_name geography 
					rename fips st_fips
					rename cngdstcd fips
					rename cd_* *
					rename pt_cd_* pt_*
					keep st_fips st_name fips geography sector_group t_* pt_t_* pct_educ_*
					rename t_* s_*
					rename pt_t_* pt_s_*
					replace sector_group = 5
					duplicates drop fips, force
					tempfile combined_cd_temp1
					save `combined_cd_temp1'		
				restore
				
		// By sector
			// National 
				preserve 
					keep fips st_name sector_group nat_* pt_nat_* natl_*
					replace fips = 0
					replace st_name = "United States"
					rename st_name geography
					rename natl_* *
					rename nat_* *
					rename pt_nat_* pt_*
					keep fips geography sector_group s_* pt_s_* pct_educ_*
					duplicates drop fips sector_group, force
					tempfile combined_nat_temp3
					save `combined_nat_temp3'
				restore

			// State
				preserve 
					keep fips st_name sector_group st_* pt_st_*
					rename st_name geography
					rename st_* *
					rename pt_st_* pt_*
					keep fips geography sector_group s_* pt_s_* pct_educ_*
					duplicates drop fips sector_group, force
					tempfile combined_st_temp3
					save `combined_st_temp3'	
				restore 
				
			// CDs
				preserve 
					keep fips st_name cngdstcd cd_name sector_group cd_* pt_cd_*
					rename cd_name geography 
					rename fips st_fips
					rename cngdstcd fips
					rename cd_* *
					rename pt_cd_* pt_*
					keep st_name st_fips fips geography sector_group s_* pt_s_* pct_educ_*
					duplicates drop fips sector_group, force
					tempfile combined_cd_temp3
					save `combined_cd_temp3'		
				restore

			
		// Append
			use `combined_nat_temp1', clear
			append using `combined_nat_temp3'
			append using `combined_st_temp1'
			append using `combined_st_temp3'
			append using `combined_cd_temp1'
			append using `combined_cd_temp3'
			
			sort fips sector_group
			
			drop 	s_ef_aian* s_dist_* s_ug_* s_gr_unsub_recip s_pplus_recip ///
					s_gplus_recip s_pell_recip s_distance_denom s_bbrr2_* ///
					s_fed_* s_pp_ug_n s_compr_nra_* s_compr_black_* ///
					s_compr_native_* s_compr_hisp_* s_compr_white_* s_compr_total_men_* ///
					s_compr_total_women_* s_compr_nhpi_* s_compr_asian_* ///
					s_compr_unk_* s_compr_twoplus_* s_ef_asian* s_ef_black* ///
					s_ef_hisp* s_ef_nhpi* s_ef_white* s_ef_twomore* s_ef_unk* ///
					s_ef_nra* s_ef_tot_men* s_ef_tot_women* s_ef_nontrad_t_fte ///
					s_ef_trad_t_fte
					
			drop 	*_aapi_* *_other_*

			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		order fips geography sector_group st_fips st_name
		
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
		
	frameappend newdists_2020
			
	// Change number format for Tableau
		ds pct_* pt_* s_cdr3 s_gr_total_tot_150 s_tuit_discount_rt
		foreach x in `r(varlist)' {
			replace `x' = (`x'*100)
		}
		
		ds fips geography sector_group st_fips st_name pct_* pt_* s_cdr3 ///
			s_gr_total_tot_150 s_tuit_discount_rt s_compr_* s_ef_tot_fte, not 
		foreach x in `r(varlist)' {
			replace `x' = (`x'/1000)
		}

	// Convert file to long format for Tableau purposes
		ds pct_educ_lessthanhs-s_netprice_more110_avg
		foreach x in `r(varlist)' {
			rename `x' m_`x'
		}
		
		reshape long m_, i(fips sector_group) j(var_name) string
		rename m_ metric_value
		
	replace sector_group = 5 if inlist(fips,808,1228,3001,3002,3714,4106,4837,4838,4808)

	save "$analysis\explorer_custom.dta", replace
	export delimited "$analysis\explorer_custom.csv", replace		

// Trend Explorer																	// All vars that have multi-year data
	use "$analysis\explorer_combined.dta", clear

	keep 	instnm fips st_name cngdstcd cd_name year ///
			census_region pell_recip sector_group ///
			debt_mdn coa_numer st_pct_educ_lessthanhs ///
			st_pct_educ_hs st_pct_educ_somecoll st_pct_educ_grad ///
			st_pct_educ_assoc st_pct_educ_bach cd_pct_educ_lessthanhs ///
			cd_pct_educ_hs cd_pct_educ_somecoll cd_pct_educ_grad ///
			cd_pct_educ_assoc cd_pct_educ_bach natl_pct_educ_lessthanhs ///
			natl_pct_educ_hs natl_pct_educ_somecoll natl_pct_educ_grad ///
			natl_pct_educ_assoc natl_pct_educ_bach ef_tot_fte ///
			ef_aian_tot_fte ef_asian_tot_fte ef_black_tot_fte ///
			ef_hisp_tot_fte ef_nhpi_tot_fte ef_white_tot_fte ///
			ef_twomore_tot_fte ef_unk_tot_fte ef_nra_tot_fte ///
			grad_debt_mdn wdraw_debt_mdn hi_inc_debt_mdn ///
			lo_inc_debt_mdn ef_tot_ftug ef_tot_ptug pplus_recip ///
			ef_tot_fte gplus_recip ug_sub_recip ug_unsub_recip ///
			gr_unsub_recip lpstafford_cnt lpstafford_amt lppplus_cnt lppplus_amt ///
			ef_tot_f* ef_tot_p* ef_*_tot_f* ef_*_tot_p* dist_denom ///
			dist_excl dist_some dist_none ef_tot_men_fte ef_tot_women_fte ///
			ef_tot_ug ef_tot_gr ef_*_tot_gr indist_tuit_numer instate_tuit_numer ///
			outstate_tuit_numer oncamp_rmbrdoth_numer ///
			offcamp_rmbrdoth_numer ef_tot_fte tot_inst_aid ///
			gross_tuition_rev netprice_denom netprice_less30_denom ///
			netprice_more110_denom netprice_tot_numer netprice_less30_numer ///
			netprice_more110_numer state_approp compr_*_tot_* compr_total_men_* ///
			compr_total_women_* gr_total_tot denom150 ug_n
			
	drop ef_*_ptug
								
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat reg {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			if "`x'" == "reg" local level census_region
			
			ds 	ef_* dist_* compr_* tot_inst_aid lp* ///				// sum at geog level & year
				ug_sub_recip ug_unsub_recip gr_unsub_recip pplus_recip ///
				gplus_recip pell_recip gr_total_tot denom150 gross_tuition_rev ///
				indist_tuit_numer instate_tuit_numer outstate_tuit_numer ///
				oncamp_rmbrdoth_numer offcamp_rmbrdoth_numer netprice_denom ///
				netprice_less30_denom netprice_more110_denom coa_numer ///
				netprice_tot_numer netprice_less30_numer netprice_more110_numer ug_n
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level' year)
			}		
			
			ds ef_tot_fte state_approp
			foreach y in `r(varlist)' {
				egen `x'_spub1_`y' = sum(`y') if inlist(sector_group,1,2), by(`level' year) missing
				egen `x'_spub_`y' = max(`x'_spub1_`y'), by(`level' year)
			}		
			
			ds 	debt_mdn grad_debt_mdn wdraw_debt_mdn lo_inc_debt_mdn ///			// median at geog level & year
				hi_inc_debt_mdn
			foreach y in `r(varlist)' {
				egen `x'_m_`y' = median(`y'), by(`level' year)
			}
		
			ds `x'_s_ef_*_tot_ftug
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_ftug
			}
			
			ds `x'_s_ef_*_tot_fte
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_fte
			}
			
			ds `x'_s_ef_tot_men_fte `x'_s_ef_tot_women_fte
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_fte
			}
			
			ds `x'_s_ef_*_tot_gr
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_gr
			}
			
			rename `x'_s_dist_denom `x'_s_distance_denom
			ds `x'_s_dist_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_distance_denom
			}
			
			rename (`x'_s_compr_total_tot_assoc `x'_s_compr_total_tot_bach ///
					`x'_s_compr_total_tot_grad `x'_s_compr_total_tot_tot) ///
					(`x'_s_compr_total_assoc `x'_s_compr_total_bach `x'_s_compr_total_grad ///
					`x'_s_compr_total)
					
			ds 	`x'_s_compr_*_tot_assoc `x'_s_compr_total_women_assoc ///
				`x'_s_compr_total_men_assoc
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_assoc
			}
			
			ds `x'_s_compr_*_tot_bach `x'_s_compr_total_women_bach ///
				`x'_s_compr_total_men_bach
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_bach
			}
			
			ds `x'_s_compr_*_tot_grad `x'_s_compr_total_women_grad ///
				`x'_s_compr_total_men_grad
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_grad
			}
			
			ds 	`x'_s_ug_sub_recip `x'_s_ug_unsub_recip `x'_s_pplus_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_ug
			}
			
			ds `x'_s_pell_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ug_n
			}
			drop `x'_s_ug_n
			
			ds `x'_s_gr_unsub_recip `x'_s_gplus_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_gr
			}
			
			gen `x'_s_st_approp_fte = `x'_spub_state_approp / `x'_spub_ef_tot_fte
			gen `x'_s_tot_inst_aid_fte = `x'_s_tot_inst_aid / `x'_s_ef_tot_fte
			drop `x'_spub_state_approp `x'_spub_ef_tot_fte
			
			gen `x'_a_lpstafford_avg = `x'_s_lpstafford_amt / `x'_s_lpstafford_cnt
			gen `x'_a_lppplus_avg = `x'_s_lppplus_amt / `x'_s_lppplus_cnt
			drop `x'_s_lpstafford_amt `x'_s_lpstafford_cnt `x'_s_lppplus_amt `x'_s_lppplus_cnt
			
			gen `x'_a_gr_total_tot_150 = `x'_s_gr_total_tot / `x'_s_denom150
			drop `x'_s_gr_total_tot `x'_s_denom150
			
			gen `x'_a_tuit_discount_rt = `x'_s_tot_inst_aid / `x'_s_gross_tuition_rev
			drop `x'_s_tot_inst_aid `x'_s_gross_tuition_rev
			
			gen `x'_a_indist_tuit_fees = `x'_s_indist_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_instate_tuit_fees = `x'_s_instate_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_outstate_tuit_fees = `x'_s_outstate_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_netprice_tot_avg = `x'_s_netprice_tot_numer / `x'_s_netprice_denom
			gen `x'_a_netprice_less30_avg = `x'_s_netprice_less30_numer / `x'_s_netprice_less30_denom
			gen `x'_a_netprice_more110_avg = `x'_s_netprice_more110_numer / `x'_s_netprice_more110_denom
			gen `x'_a_coa = `x'_s_coa_numer / `x'_s_ef_tot_fte
			gen `x'_a_oncamp_rmbrdoth = `x'_s_oncamp_rmbrdoth_numer / `x'_s_ef_tot_fte
			gen `x'_a_offcamp_rmbrdoth = `x'_s_offcamp_rmbrdoth_numer / `x'_s_ef_tot_fte
			
			drop `x'_s_indist_tuit_numer `x'_s_instate_tuit_numer ///
				`x'_s_outstate_tuit_numer `x'_s_netprice_tot_numer ///
				`x'_s_netprice_denom `x'_s_netprice_less30_numer ///
				`x'_s_netprice_less30_denom `x'_s_netprice_more110_numer ///
				`x'_s_netprice_more110_denom `x'_s_coa_numer `x'_s_oncamp_rmbrdoth_numer ///
				`x'_s_offcamp_rmbrdoth_numer
		}
		
		drop sector_group

	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name census_region year nat_* pt_nat_* natl_*
				replace fips = 0
				replace st_name = "United States"
				replace census_region = 0
				rename st_name geography
				duplicates drop fips year, force
				rename natl_* *
				rename nat_* *
				rename pt_nat_* pt_*
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name census_region year st_* pt_st_*
				rename st_name geography
				duplicates drop fips year, force
				rename st_* *
				rename pt_st_* pt_*
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name census_region year cd_* pt_cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips year, force
				rename cd_* *
				rename pt_cd_* pt_*
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Census Regions 
			preserve 
				keep census_region year reg_* pt_reg_*
				decode census_region, gen(geography)
				duplicates drop census_region year, force
				rename reg_* *
				rename pt_reg_* pt_*
				tempfile combined_reg_temp
				save `combined_reg_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			append using `combined_reg_temp'
			
			rename s_ef_tot_fte ef_tot_fte
			
			drop 	s_ef_* s_compr_* s_dist_* s_ug_* s_gr_* s_pplus_recip ///
					s_gplus_recip s_pell_recip s_distance_denom
					
			rename ef_tot_fte s_ef_tot_fte
			
			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
	// Adjust cost metrics for inflation using CPI
		destring year, replace
		merge m:1 year using "C:\Users\jared\Desktop\work\public_data\cpi.dta"
		drop if _merge != 3
		drop _merge 
		
		gen mry_cpi1 = cpi if year == 2021
		egen mry_cpi = max(mry_cpi1)
		
		foreach x in a_indist_tuit_fees a_instate_tuit_fees a_outstate_tuit_fees ///
				a_netprice_tot_avg a_coa a_oncamp_rmbrdoth ///
				a_offcamp_rmbrdoth m_debt_mdn m_grad_debt_mdn ///
				m_wdraw_debt_mdn m_lo_inc_debt_mdn m_hi_inc_debt_mdn ///
				s_st_approp_fte s_tot_inst_aid_fte a_lpstafford_avg ///
				a_lppplus_avg {
					replace `x' = ((`x' / cpi) * mry_cpi)
				}
				
		drop cpi mry_cpi mry_cpi1
		tostring year, replace
		
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
		drop if inlist(fips,6098,6698,6998,7298,7898,-2)								// CDs in territories for prior years
		
	frameappend newdists_2020
	
	sort fips year
		
	save "$analysis\explorer_trend.dta", replace
	export delimited "$analysis\explorer_trend.csv", replace
	
// Comparison Tool																	
	use "$analysis\explorer_combined.dta", clear
	ds 	bbrr2_fed_ug_* bbrr2_fed_ugnocomp_* bbrr2_fed_gr_n ///
		bbrr2_pp_ug_* cdr3_numer cdr3_denom
	
	foreach x in `r(varlist)' {
		gen `x'_t = `x' if year == "2018"											// Assign 2018 to 2020 for all repayment/default metrics (to keep)
		egen `x'_t2 = max(`x'_t), by(unitid)
		replace `x' = `x'_t2
		drop `x'_t `x'_t2
	}
		
	keep if year == "2021"															// keep most recent year (and others I changed above)

	keep 	instnm fips st_name cngdstcd cd_name census_region sector_group pell_recip ///
			debt_mdn coa_numer cdr3_numer cdr3_denom st_pct_educ_lessthanhs ///
			st_pct_educ_hs st_pct_educ_somecoll st_pct_educ_grad ///
			st_pct_educ_assoc st_pct_educ_bach cd_pct_educ_lessthanhs ///
			cd_pct_educ_hs cd_pct_educ_somecoll cd_pct_educ_grad ///
			cd_pct_educ_assoc cd_pct_educ_bach natl_pct_educ_lessthanhs ///
			natl_pct_educ_hs natl_pct_educ_somecoll natl_pct_educ_grad ///
			natl_pct_educ_assoc natl_pct_educ_bach ef_tot_fte ///
			ef_aian_tot_fte ef_asian_tot_fte ef_black_tot_fte ///
			ef_hisp_tot_fte ef_nhpi_tot_fte ef_white_tot_fte ///
			ef_twomore_tot_fte ef_unk_tot_fte ef_nra_tot_fte ///
			grad_debt_mdn wdraw_debt_mdn hi_inc_debt_mdn ///
			lo_inc_debt_mdn ef_tot_ftug ef_tot_ptug pplus_recip ///
			ef_tot_fte gplus_recip ug_sub_recip ug_unsub_recip ///
			gr_unsub_recip lpstafford_cnt lpstafford_amt lppplus_cnt lppplus_amt ///
			ef_tot_f* ef_tot_p* ef_*_tot_f* ef_*_tot_p* ef_tot_gr dist_denom ///
			dist_excl dist_some dist_none ef_tot_men_fte ef_tot_women_fte ///
			ef_nontrad_t_fte ef_tot_ug indist_tuit_numer instate_tuit_numer ///
			outstate_tuit_numer oncamp_rmbrdoth_numer offcamp_rmbrdoth_numer ///
			ef_tot_fte tot_inst_aid ef_trad_t_fte ef_*_tot_gr ///
			gross_tuition_rev netprice_denom netprice_less30_denom ///
			netprice_more110_denom netprice_tot_numer netprice_less30_numer ///
			netprice_more110_numer state_approp compr_*_tot_* compr_total_men_* ///
			compr_total_women_*	bbrr2_fed_ug_* bbrr2_fed_ugnocomp_* bbrr2_fed_gr_n ///
			bbrr2_pp_ug_* gr_total_tot denom150 ug_n
			
	renvars *_paidinfull, subst(paidinfull pif)										// shorten var names of repayment rates
	renvars *_discharge, subst(discharge disch)
	renvars *_ugnocomp_*, subst(ugnocomp ugnc)
	renvars *_makeprog, subst(makeprog mkprg)
	
	/*
	ds bbrr2*
	foreach x in `r(varlist)' {														// recode repayment rates for calc
		recode `x' (.=0)
	}
	*/
	
	// Temporarily rename totals for loop purpose 
		rename 	(bbrr2_fed_ug_n bbrr2_fed_ugnc_n bbrr2_pp_ug_n) ///
				(fed_ug_n fed_ugnc_n pp_ug_n)
				
	// Create totals from %s so we can calc % aggregates
		ds bbrr2_fed_ug_* 
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * fed_ug_n
			drop `x'
		}
		
		ds bbrr2_fed_ugnc_*
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * fed_ugnc_n
			drop `x'
		}
		
		ds bbrr2_pp_ug_*
		foreach x in `r(varlist)' {
			gen `x'_1 = `x' * pp_ug_n
			drop `x'
		}
			
	drop ef_*_ptug
	
	// CD, ST, & Nat estimates
		gen nat_num = 1
		foreach x in cd st nat {
			if "`x'" == "cd" local level cngdstcd 
			if "`x'" == "st" local level fips 
			if "`x'" == "nat" local level nat_num
			
			ds 	ef_* dist_* compr_* tot_inst_aid lp* ///				// sum at geog level
				ug_sub_recip ug_unsub_recip gr_unsub_recip pplus_recip ///
				gplus_recip pell_recip fed_ug_n fed_ugnc_n ///
				pp_ug_n bbrr2_*_1 gr_total_tot denom150 gross_tuition_rev ///
				coa_numer cdr3_numer cdr3_denom indist_tuit_numer instate_tuit_numer ///
				outstate_tuit_numer oncamp_rmbrdoth_numer offcamp_rmbrdoth_numer ///
				netprice_denom netprice_less30_denom ///
				netprice_more110_denom netprice_tot_numer netprice_less30_numer ///
				netprice_more110_numer ug_n
			foreach y in `r(varlist)' {
				egen `x'_s_`y' = sum(`y'), by(`level') missing
			}	
			
			ds ef_tot_fte state_approp
			foreach y in `r(varlist)' {
				egen `x'_spub1_`y' = sum(`y') if inlist(sector_group,1,2), by(`level') missing
				egen `x'_spub_`y' = max(`x'_spub1_`y'), by(`level')
			}	
			
			ds 	debt_mdn grad_debt_mdn wdraw_debt_mdn lo_inc_debt_mdn ///			// median at geog level
				hi_inc_debt_mdn
			foreach y in `r(varlist)' {
				egen `x'_m_`y' = median(`y'), by(`level')
			}
		
			ds `x'_s_ef_*_tot_ftug
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_ftug
			}
			
			ds `x'_s_ef_*_tot_fte `x'_s_ef_tot_men_fte `x'_s_ef_tot_women_fte ///
				`x'_s_ef_nontrad_t_fte `x'_s_ef_trad_t_fte
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_fte
			}
			
			ds `x'_s_ef_*_tot_gr
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_gr
			}
			
			ds `x'_s_bbrr2_fed_ug_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_fed_ug_n
			}
			
			ds `x'_s_bbrr2_fed_ugnc_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_fed_ugnc_n
			}
			
			ds `x'_s_bbrr2_pp_ug_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_pp_ug_n
			}
			
			rename `x'_s_dist_denom `x'_s_distance_denom
			ds `x'_s_dist_*
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_distance_denom
			}
			
			rename (`x'_s_compr_total_tot_assoc `x'_s_compr_total_tot_bach ///
					`x'_s_compr_total_tot_grad `x'_s_compr_total_tot_tot) ///
					(`x'_s_compr_total_assoc `x'_s_compr_total_bach `x'_s_compr_total_grad ///
					`x'_s_compr_total)
					
			ds 	`x'_s_compr_*_tot_assoc
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_assoc
			}
			
			ds `x'_s_compr_*_tot_bach
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_bach
			}
			
			ds `x'_s_compr_*_tot_grad
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total_grad
			}
			
			ds `x'_s_compr_total_men_tot `x'_s_compr_total_women_tot
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_compr_total
			}
			
			ds 	`x'_s_ug_sub_recip `x'_s_ug_unsub_recip `x'_s_pplus_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_ug
			}
			
			ds 	`x'_s_pell_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ug_n
			}			
			drop `x'_s_ug_n
			
			ds `x'_s_gr_unsub_recip `x'_s_gplus_recip
			foreach y in `r(varlist)' {
				gen pt_`y' = `y' / `x'_s_ef_tot_gr
			}
			
			gen `x'_s_st_approp_fte = `x'_spub_state_approp / `x'_spub_ef_tot_fte
			gen `x'_s_tot_inst_aid_fte = `x'_s_tot_inst_aid / `x'_s_ef_tot_fte
			drop `x'_spub_state_approp `x'_spub_ef_tot_fte
			
			gen `x'_a_lpstafford_avg = `x'_s_lpstafford_amt / `x'_s_lpstafford_cnt
			gen `x'_a_lppplus_avg = `x'_s_lppplus_amt / `x'_s_lppplus_cnt
			drop `x'_s_lpstafford_amt `x'_s_lpstafford_cnt `x'_s_lppplus_amt `x'_s_lppplus_cnt
			
			gen `x'_a_gr_total_tot_150 = `x'_s_gr_total_tot / `x'_s_denom150
			drop `x'_s_gr_total_tot `x'_s_denom150
			
			gen `x'_a_tuit_discount_rt = `x'_s_tot_inst_aid / `x'_s_gross_tuition_rev
			drop `x'_s_tot_inst_aid `x'_s_gross_tuition_rev
			
			gen `x'_a_indist_tuit_fees = `x'_s_indist_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_instate_tuit_fees = `x'_s_instate_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_outstate_tuit_fees = `x'_s_outstate_tuit_numer / `x'_s_ef_tot_fte
			gen `x'_a_netprice_tot_avg = `x'_s_netprice_tot_numer / `x'_s_netprice_denom
			gen `x'_a_netprice_less30_avg = `x'_s_netprice_less30_numer / `x'_s_netprice_less30_denom
			gen `x'_a_netprice_more110_avg = `x'_s_netprice_more110_numer / `x'_s_netprice_more110_denom
			gen `x'_a_coa = `x'_s_coa_numer / `x'_s_ef_tot_fte
			gen `x'_a_oncamp_rmbrdoth = `x'_s_oncamp_rmbrdoth_numer / `x'_s_ef_tot_fte
			gen `x'_a_offcamp_rmbrdoth = `x'_s_offcamp_rmbrdoth_numer / `x'_s_ef_tot_fte
			gen `x'_a_cdr3 = `x'_s_cdr3_numer / `x'_s_cdr3_denom
			
			drop `x'_s_indist_tuit_numer `x'_s_instate_tuit_numer ///
				`x'_s_outstate_tuit_numer `x'_s_netprice_tot_numer ///
				`x'_s_netprice_denom `x'_s_netprice_less30_numer ///
				`x'_s_netprice_less30_denom `x'_s_netprice_more110_numer ///
				`x'_s_netprice_more110_denom `x'_s_coa_numer `x'_s_oncamp_rmbrdoth_numer ///
				`x'_s_offcamp_rmbrdoth_numer `x'_s_cdr3_numer `x'_s_cdr3_denom
		}
		
		drop sector_group

	// Split and append to make long form
		// National 
			preserve 
				keep fips st_name census_region nat_* pt_nat_* natl_*
				replace fips = 0
				replace st_name = "United States"
				replace census_region = 0
				rename st_name geography
				duplicates drop fips, force
				rename natl_* *
				rename nat_* *
				rename pt_nat_* pt_*
				drop num
				tempfile combined_nat_temp
				save `combined_nat_temp'
			restore

		// State
			preserve 
				keep fips st_name census_region st_* pt_st_*
				rename st_name geography
				duplicates drop fips, force
				rename st_* *
				rename pt_st_* pt_*
				tempfile combined_st_temp
				save `combined_st_temp'	
			restore 
			
		// CDs
			preserve 
				keep fips st_name cngdstcd cd_name census_region cd_* pt_cd_*
				rename cd_name geography 
				rename fips st_fips
				rename cngdstcd fips
				duplicates drop fips, force
				rename cd_* *
				rename pt_cd_* pt_*
				tempfile combined_cd_temp
				save `combined_cd_temp'		
			restore 
			
		// Append
			use `combined_nat_temp', clear
			append using `combined_st_temp'
			append using `combined_cd_temp'
			
			rename s_ef_tot_fte ef_tot_fte
			
			drop 	s_ef_* s_compr_* s_dist_* s_ug_* s_gr_* s_pplus_recip ///
					s_gplus_recip s_pell_recip s_distance_denom s_bbrr2_*
					
			rename ef_tot_fte s_ef_tot_fte
					
			drop 	*_aapi_* *_other_*

			replace st_fips = fips if st_fips == .
			replace st_name = geography if st_name == ""
			
		drop if inlist(fips,6000,6600,6900,7200,7800)								// Remove duplicates for CDs in territories
			
	frameappend newdists_2020
	sort fips

	save "$analysis\explorer_compare.dta", replace
	export delimited "$analysis\explorer_compare.csv", replace				
			
			
			
			
			
			


	

