********************************************************************************
// Purpose: Pull in FSA data and clean it
// Author: Jared Colston
// Last Updated: 5.11.2023
// Last Updated By: Jared Colston
********************************************************************************

clear all

********************************************************************************
**# [i] DEPENDENCIES ----------------------------------------------------------|
/* 	This .do file is stand-alone; it pulls directly from the FSA data center,
	produces a cleaned file at district and state levels, and removes 
	intermediary files. It can be run separately. */
	
********************************************************************************
**# [ii] USER-WRITTEN COMMANDS ------------------------------------------------|

	/*

	*/

********************************************************************************
**# [1] FILE PATHWAYS ---------------------------------------------------------|
	
	global path "C:\Users\jared\Desktop\work\pnpi\data\fsa"							// Here you can set overall folder for FSA to run as stand-alone
	*capture global path "$fsapath"															// If you use the combined option in zipped folder
	
	*pathway key:
		*raw = untransformed files from data source
		*temp = transformed files, not ready for analysis
		*analysis = final cleaned dataframe
	
	capture mkdir "$path\raw"																// Create folders if not already made
	capture mkdir "$path\temp"
	capture mkdir "$path\backup"
	
	global raw "$path\raw"
	global temp "$path\temp"
	global backup "$path\backup"
	global analysis "$path"

	
********************************************************************************
**# [2] GET DATA FROM FSA DATA CENTER -----------------------------------------|

// Loan volume	
	foreach x in 2010 2011 {
		local yr = `x' + 1
		copy https://studentaid.gov/sites/default/files/DL_Dashboard_AY`x'_`yr'_Q4.xls "$raw\dl_`x'.xlsx", replace
		import excel "$raw\dl_`x'.xlsx", sheet("Award Year Summary") cellrange(A7) clear
		rename 	(A B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB ///
					AC AD AE AF AG AH AI) ///
				(opeid instnm stabbr zipcode sch_type ug_sub_recip ug_sub_orig_num ///
				ug_sub_orig_amt ug_sub_disb_num ug_sub_disb_amt gr_sub_recip ///
				gr_sub_orig_num gr_sub_org_amt gr_sub_disb_num gr_sub_orig_amt ///
				ug_unsub_recip ug_unsub_orig_num ug_unsub_orig_amt ///
				ug_unsub_disb_num ug_unsub_disb_amt gr_unsub_recip ///
				gr_unsub_orig_num gr_unsub_org_amt gr_unsub_disb_num ///
				gr_unsub_orig_amt pplus_recip pplus_orig_num pplus_orig_amt ///
				pplus_disb_num pplus_disb_amt gplus_recip gplus_orig_num ///
				gplus_orig_amt gplus_disb_num gplus_disb_amt)
				
		ds, has(type string)
		foreach y in `r(varlist)' {
			replace `y' = "" if `y' == "-"
			destring `y', replace
		}
		
		drop if opeid == .
		gen year = "`x'"
		save "$temp\dl_`x'.dta", replace
	}

	forvalues x = 2012/2021 {
		local yr = `x' + 1
		if inlist(`x',2012,2013) {
			local filepath "https://studentaid.gov/sites/default/files/"
			local cell A7
			local filename1 DL_
			local filename2 AY
			local filename3 Q
			local filename4 Dashboard_
			local yr2 _
			local yr3 _
		}
		if inlist(`x',2014,2015,2016) {
			local filepath "https://studentaid.gov/sites/default/files/fsawg/datacenter/library/"
			local cell A7
			local filename1 DL_
			local filename2 AY
			local filename3 Q
			local filename4 Dashboard_
			local yr2 _
			local yr3 _
		}
		if inlist(`x',2017) {
			local filepath "https://studentaid.gov/sites/default/files/fsawg/datacenter/library/"
			local cell A8
			local filename1 DL_
			local filename2 AY
			local filename3 Q
			local filename4 Dashboard_
			local yr2 _
			local yr3 _
		}
		if inrange(`x',2018,2021) {
			local filepath "https://studentaid.gov/sites/default/files/fsawg/datacenter/library/"
			local cell A8
			local filename1 dl-
			local filename2 ay
			local filename3 q
			local filename4 dashboard-
			local yr2 -
			local yr3 -
		}		
		copy "`filepath'`filename1'`filename4'`filename2'`x'`yr2'`yr'`yr3'`filename3'4.xls" "$raw\dl_`x'.xlsx", replace
		import excel "$raw\dl_`x'.xlsx", sheet("Award Year Summary") cellrange(`cell') clear
		rename 	(A B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB ///
					AC AD) ///
				(opeid instnm stabbr zipcode sch_type ug_sub_recip ug_sub_orig_num ///
				ug_sub_orig_amt ug_sub_disb_num ug_sub_disb_amt ///
				ug_unsub_recip ug_unsub_orig_num ug_unsub_orig_amt ///
				ug_unsub_disb_num ug_unsub_disb_amt gr_unsub_recip ///
				gr_unsub_orig_num gr_unsub_org_amt gr_unsub_disb_num ///
				gr_unsub_orig_amt pplus_recip pplus_orig_num pplus_orig_amt ///
				pplus_disb_num pplus_disb_amt gplus_recip gplus_orig_num ///
				gplus_orig_amt gplus_disb_num gplus_disb_amt)
		
		capture replace zipcode = subinstr(zipcode,"-","",.)
		
		ds, has(type string)
		foreach y in `r(varlist)' {
			replace `y' = trim(`y')
			replace `y' = "" if `y' == "-"
			destring `y', replace
		}
		
		drop if opeid == .
		gen year = "`x'"
		save "$temp\dl_`x'.dta", replace
	}
	
	// Append
		use "$temp\dl_2010.dta", clear
		forvalues i = 2011/2021 {
			append using "$temp\dl_`i'.dta"
		}
		
		drop AE AF zipcode
		save "$temp\dl_comb.dta", replace

// Grant volume 
	copy https://studentaid.gov/sites/default/files/Q41011AY.xls "$raw\grant_2010.xlsx", replace
	import excel "$raw\grant_2010.xlsx", sheet("Q4 1011 YTD") cellrange(A7) clear
	rename (A B C D E F G H I J K L M N O) ///
		(opeid instnm stabbr zipcode sch_type pell_recip pell_amt ///
			acad_recip acad_amt smart_recip smart_amt teach_recip ///
			teach_amt iraq_recip iraq_amt)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}

	drop if opeid == .
	gen year = "2010"
	save "$temp\grant_2010.dta", replace
	
	foreach x in 1112 1213 1314 1415 1516 1617 1718 {
		local yr = "20" + substr("`x'",1,2)
		if inlist(`x',1718) local cell A8
		else local cell A7
		if inlist(`x',1112,1213) local sheet "Q4 `x' YTD"
		else local sheet "Award Year Summary"
		
		if inlist(`x',1011,1112,1213) {
			local filepath https://studentaid.gov/sites/default/files/
		}
		if inlist(`x',1314,1415,1516,1617,1718) {
			local filepath https://studentaid.gov/sites/default/files/fsawg/datacenter/library/
		}
		
		copy "`filepath'Q4`x'AY.xls" "$raw\grant_`yr'.xlsx", replace
		import excel "$raw\grant_`yr'.xlsx", sheet(`sheet') cellrange(`cell') clear
		rename (A B C D E F G H I J K) ///
			(opeid instnm stabbr zipcode sch_type pell_recip pell_amt teach_recip ///
				teach_amt iraq_recip iraq_amt)
		
		ds, has(type string)
		foreach y in `r(varlist)' {
			replace `y' = trim(`y')
			replace `y' = "" if `y' == "-"
			destring `y', replace
		}
		
		drop if opeid == .
		gen year = "`yr'"
		save "$temp\grant_`yr'.dta", replace		
	}
	
	foreach x in 18 19 20 21 {
		local x2 = `x' + 1
		local yr = "20" + "`x'"
		copy https://studentaid.gov/sites/default/files/fsawg/datacenter/library/grants-ay`x'-`x2'-q4.xls "$raw\grant_`yr'.xlsx", replace
		import excel "$raw\grant_`yr'.xlsx", sheet("Award Year Summary") cellrange(A8) clear
		rename (A B C D E F G H I J K) ///
			(opeid instnm stabbr zipcode sch_type pell_recip pell_amt teach_recip ///
				teach_amt iraq_recip iraq_amt)
		
		ds, has(type string)
		foreach y in `r(varlist)' {
			replace `y' = trim(`y')
			replace `y' = "" if `y' == "-"
			destring `y', replace
		}
		
		drop if opeid == .
		gen year = "`yr'"
		save "$temp\grant_`yr'.dta", replace		
	}
	
	// Append
		use "$temp\grant_2010.dta", clear 
		forvalues i = 2011/2021 {
			append using "$temp\grant_`i'.dta"
		}
		
		drop L zipcode
		save "$temp\grant_comb.dta", replace

// Campus-based programs 
	*formatting is completely erratic, not much looping possible
	
	*2010
	copy https://studentaid.gov/sites/default/files/2010-2011CBData.xls "$raw\campusbased_2010.xlsx", replace
	import excel "$raw\campusbased_2010.xlsx", sheet("AY2010-11") cellrange(A5) clear
	rename (A B C D E F G H I J K L M N) ///
		(opeid instnm stabbr zipcode sch_type fws_recip fws_award fws_disb ///
			perkins_recip perkins_award perkins_disb seog_recip seog_award ///
			seog_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = subinstr(`y',"$","",.)
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2010"
	save "$temp\campusbased_2010.dta", replace
	
	*2011
	copy https://studentaid.gov/sites/default/files/2011-2012CBData.xls "$raw\campusbased_2011.xlsx", replace
	import excel "$raw\campusbased_2011.xlsx", sheet("AY2011-12") cellrange(A5) clear
	rename (A B C D E F G H I J K L M N) ///
		(opeid instnm stabbr zipcode sch_type fws_recip fws_award fws_disb ///
			perkins_recip perkins_award perkins_disb seog_recip seog_award ///
			seog_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2011"
	save "$temp\campusbased_2011.dta", replace
	
	*2012
	copy https://studentaid.gov/sites/default/files/2012-13CampusBasedFunding.xls "$raw\campusbased_2012.xlsx", replace
	import excel "$raw\campusbased_2012.xlsx", sheet("2012-13") cellrange(A5) clear
	rename (A B C D E F G H I J K L M N) ///
		(opeid instnm stabbr zipcode sch_type fws_recip fws_award fws_disb ///
			perkins_recip perkins_award perkins_disb seog_recip seog_award ///
			seog_disb)
			
	replace zipcode = subinstr(zipcode,"-","",.)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2012"
	save "$temp\campusbased_2012.dta", replace
	
	*2013
	copy https://studentaid.gov/sites/default/files/2013-14CampusBased.xls "$raw\campusbased_2013.xlsx", replace
	import excel "$raw\campusbased_2013.xlsx", sheet("AY2013-14") cellrange(A5) clear
	rename (A B C D E F G H I J K L M N) ///
		(opeid instnm stabbr zipcode sch_type fws_recip fws_award fws_disb ///
			perkins_recip perkins_award perkins_disb seog_recip seog_award ///
			seog_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2013"
	save "$temp\campusbased_2013.dta", replace
	
	*2014
	copy https://studentaid.gov/sites/default/files/2014-15CampusBased.xls "$raw\campusbased_2014.xlsx", replace
	import excel "$raw\campusbased_2014.xlsx", sheet("AY2014-15") cellrange(A5) clear
	rename (A B C D E F G H I J K L M N) ///
		(opeid instnm stabbr zipcode sch_type fws_recip fws_award fws_disb ///
			perkins_recip perkins_award perkins_disb seog_recip seog_award ///
			seog_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2014"
	save "$temp\campusbased_2014.dta", replace
	
	*2015
	copy https://studentaid.gov/sites/default/files/fsawg/datacenter/library/2015-16CampusBased.xls "$raw\campusbased_2015.xlsx", replace
	import excel "$raw\campusbased_2015.xlsx", sheet("2015-2016 CB Data") cellrange(A5) clear
	rename (A B C D E F G H I J K L M N) ///
		(opeid instnm stabbr zipcode sch_type fws_recip fws_award fws_disb ///
			perkins_recip perkins_award perkins_disb seog_recip seog_award ///
			seog_disb)
	
	replace zipcode = subinstr(zipcode,"-","",.)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2015"
	save "$temp\campusbased_2015.dta", replace
	
	*2016
	copy https://studentaid.gov/sites/default/files/fsawg/datacenter/library/2016-17CampusBased.xls "$raw\campusbased_2016.xlsx", replace
	import excel "$raw\campusbased_2016.xlsx", sheet("2016-17 CB Data") cellrange(A5) clear 
	rename (A B C D E F G H I J K L M) ///
		(opeid instnm stabbr zipcode sch_type perkins_recip perkins_disb ///
			seog_award seog_recip seog_disb fws_award fws_recip fws_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2016"
	save "$temp\campusbased_2016.dta", replace
	
	*2017
	copy https://studentaid.gov/sites/default/files/ay17-18-campus-based.xls "$raw\campusbased_2017.xlsx", replace
	import excel "$raw\campusbased_2017.xlsx", sheet("2017-18 CB Data") cellrange(A5) clear 
	rename (A B C D E F G H I J K L) ///
		(opeid instnm stabbr sch_type perkins_recip perkins_disb ///
			seog_award seog_recip seog_disb fws_award fws_recip fws_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2017"
	save "$temp\campusbased_2017.dta", replace
	
	*2018
	copy https://studentaid.gov/sites/default/files/fsawg/datacenter/library/ay18-19-campus-based.xls "$raw\campusbased_2018.xlsx", replace
	import excel "$raw\campusbased_2018.xlsx", sheet("2018-2019 CB Data") cellrange(A4) clear 
	rename (A B C D E F G H I J K L M) ///
		(opeid instnm stabbr zipcode sch_type perkins_recip perkins_disb ///
			seog_award seog_recip seog_disb fws_award fws_recip fws_disb)
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2018"
	save "$temp\campusbased_2018.dta", replace
	
	*2019
	copy https://studentaid.gov/sites/default/files/fsawg/datacenter/library/ay19-20-campus-based.xls "$raw\campusbased_2019.xlsx", replace
	import excel "$raw\campusbased_2019.xlsx", sheet("2019-2020") cellrange(A5) clear
	rename (A B C D E F G H I J K) ///
		(opeid instnm stabbr zipcode sch_type seog_award seog_recip ///
			seog_disb fws_award fws_recip fws_disb)
	
	replace opeid = "" if regexm(opeid,"[0-9]$") == 0								// Remove non-numeric strings
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2019"
	save "$temp\campusbased_2019.dta", replace
	
	*2020
	copy https://studentaid.gov/sites/default/files/fsawg/datacenter/library/ay20-21-campus-based.xls "$raw\campusbased_2020.xlsx", replace
	import excel "$raw\campusbased_2020.xlsx", sheet("2020-2021") cellrange(A5) clear
	rename (A B C D E F G H I J K) ///
		(opeid instnm stabbr zipcode sch_type seog_award seog_recip ///
			seog_disb fws_award fws_recip fws_disb)
	
	replace opeid = "" if regexm(opeid,"[0-9]$") == 0								// Remove non-numeric strings
	
	ds, has(type string)
	foreach y in `r(varlist)' {
		replace `y' = trim(`y')
		replace `y' = "" if `y' == "-"
		destring `y', replace
	}
	
	drop if opeid == .
	gen year = "2020"
	save "$temp\campusbased_2020.dta", replace
	
	// Append
		use "$temp\campusbased_2010.dta", clear
		forvalues i = 2011/2020 {
			append using "$temp\campusbased_`i'.dta"
		}
	
		drop O L zipcode
		save "$temp\campusbased_comb.dta", replace
	
********************************************************************************
**# [3] COMBINE & CLEAN DATA --------------------------------------------------|	
	
	use "$temp\dl_comb.dta", clear
	merge 1:1 opeid year using "$temp\grant_comb.dta"
	drop _merge
	merge 1:1 opeid year using "$temp\campusbased_comb.dta"
	drop _merge 
	
	replace sch_type = strproper(sch_type)
	replace sch_type = subinstr(sch_type,"-"," ",.)
	
	tostring opeid, replace
	gen opeid2 = substr(8 * "0", 1, 8 - length(opeid)) + opeid
	
	drop if year == "2010"
	
	save "$analysis\fsa_cleaned.dta", replace
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	




