********************************************************************************
// Purpose: Pull in and clean IPEDS data
// Author: Jared Colston
// Last Updated: 1.19.2024
// Last Updated By: Jared Colston
********************************************************************************

clear all

********************************************************************************
**# [i] DEPENDENCIES ----------------------------------------------------------|
/* 	This .do file is stand-alone; it pulls directly from IPEDS,
	produces a cleaned file at the institution level, and removes 
	intermediary files. It can be run separately. */
	
********************************************************************************
**# [ii] USER-WRITTEN COMMANDS ------------------------------------------------|

	/*
		ssc install renvars
		ssc install fs
		ssc install ereplace
	*/
	
********************************************************************************
**# [iii] MOST RECENT COLLECTION & DATA YEARS ---------------------------------|
/* https://nces.ed.gov/ipeds/use-the-data/timing-of-ipeds-data-collection

Directory Information -
	Collection: Fall 2021
	Data: 		2021-2022 Academic Year
	Lag:		Current Year
Student Charges -
	Collection: Fall 2021
	Data:		2021-2022 Academic Year
	Lag:		Current Year
Fall Enrollment -
	Collection: Spring 2022
	Data:		Fall 2021
	Lag:		Most Recent Fall Term
Completions - 
	Collection: Fall 2021
	Data:		July 1, 2020 - June 30, 2021
	Lag:		Prior Year
Finances - 
	Collection: Spring 2022
	Data:		Fiscal Year 2021
	Lag:		Prior Year
Financial Aid - 
	Collection: Winter 2021/2022
	Data:		July 1, 2020 - June 30, 2021
	Lag:		Prior Year
Graduation Rates - 
	Collection: Winter 2021/2022
	Data:		4-year institutions cohort entering Fall 2015; 2-year institutions cohort entering Fall 2018
	Lag:		6- and 3-years prior, respectively

*/

********************************************************************************
**# [1] FILE PATHWAYS ---------------------------------------------------------|

	global path "C:\Users\jared\Desktop\work\pnpi\data\ipeds"					// Here you can set overall folder for IPEDS to run as stand-alone
	*capture global path "$ipedspath"														// If you use the combined option in zipped folder
	
	*pathway key:
		*raw = untransformed files from data source
		*temp = transformed files, not ready for analysis
		*analysis = final cleaned dataframe
	
	capture mkdir "$path\raw"																// Create folders if not already made
	capture mkdir "$path\temp"
	capture mkdir "$path\backup"
	
	global raw "$path\raw"
	global temp "$path\temp"
	global backup "$path\backup"
	global analysis "$path"
	
	
********************************************************************************
**# [2] UPDATE COLLECTION YEAR ------------------------------------------------|

	global mry 2021
	global tenyear 2011
	global tenyear_append 2012
	global tenyear_dist 2013														// Use for distance ed loop, starts at 2012

	
********************************************************************************
**# [3] GET DATA FROM IPEDS ---------------------------------------------------|

	cd "${raw}"

// Directory info -------------------------------------------------------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}
	
	forvalues x = `tenyear'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/HD`x'.zip . , replace		// Un-comment on first run to get raw files
		*unzipfile HD`x', replace
		import delimited "hd`x'.csv", varn(1) clear
		gen year = "`x'"
		tostring opeid, replace
		save "hd`x'.dta", replace		
	}
	
	// Append
		use hd`tenyear'.dta, clear 
		forvalues x = `tenyear_append'/`mry' {
			append using "hd`x'.dta", force
		}
		
		save "$temp\hd_`tenyear'_`mry'.dta", replace
		

// Student Charges ------------------------------------------------------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}
	
	forvalues x = `tenyear'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/IC`x'_AY.zip . , replace	// Un-comment on first run to get raw files
		*unzipfile ic`x'_ay.zip, replace
		import delimited "ic`x'_ay.csv", varn(1) clear
		keep unitid chg1ay3 chg2ay3 chg3ay3 chg4ay3 chg5ay3 chg6ay3 ///
			chg7ay3 chg8ay3 chg9ay3
			
		rename 	(chg1ay3 chg2ay3 chg3ay3 chg4ay3 chg5ay3 chg6ay3 ///
					chg7ay3 chg8ay3 chg9ay3) ///
				(indist_tuit_fees instate_tuit_fees outstate_tuit_fees ///
					books_supp oncampus_rmbrd oncampus_other ///
					offcampus_nfam_rmbrd offcampus_nfam_other offcampus_fam_other)
		gen year = "`x'"
		save "ic`x'_ay.dta", replace
	}

	// Append 
		use ic`tenyear'_ay.dta, clear
		forvalues i = `tenyear_append'/`mry' {
			append using ic`i'_ay.dta
		}
		
		save "$temp\tuition_`tenyear'_`mry'.dta", replace
		

// Fall Enrollment (Race/ethnicity, gender, age, retention rates, distance ed) |
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}

	*race/ethnicity & gender
	forvalues x = `tenyear'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/EF`x'A.zip . , replace		// Un-comment on first run to get raw files
		*unzipfile EF`x'A, replace
		import delimited "ef`x'a.csv", varn(1) clear
		save "ef`x'a.dta", replace													// Save raw file 
		
		foreach y in 29 8 22 11 25 {												// save by student level
			if `y' == 29 	local level ""
			if `y' == 8 	local level "_ftug"
			if `y' == 22 	local level "_ptug"
			if `y' == 11 	local level "_ftgr"
			if `y' == 25	local level "_ptgr"
			
			preserve 
				keep if line == `y'
				gen year = "`x'"
				save "ef`x'_a`level'.dta", replace
			restore 
		}
	}

	foreach x in "" "_ftug" "_ptug" "_ftgr" "_ptgr" {
		use "ef`tenyear'_a`x'.dta", clear
		forvalues y = `tenyear_append'/`mry' {
			append using "ef`y'_a`x'.dta"
		}
		
		rename (eftotlt	eftotlm	eftotlw	efaiant	efaianm	efaianw	efasiat	///
				efasiam	efasiaw	efbkaat	efbkaam	efbkaaw	efhispt	efhispm	///
				efhispw	efnhpit	efnhpim	efnhpiw	efwhitt	efwhitm	efwhitw	///
				ef2mort	ef2morm	ef2morw	efunknt	efunknm	efunknw	efnralt	///
				efnralm	efnralw) ///
			(ef_tot`x' ef_tot_men`x' ef_tot_women`x' ef_aian_tot`x' ///
				ef_aian_men`x' ef_aian_women`x' ef_asian_tot`x' ///
				ef_asian_men`x' ef_asian_women`x' ef_black_tot`x' ///
				ef_black_men`x' ef_black_women`x' ef_hisp_tot`x' ef_hisp_men`x' ///
				ef_hisp_women`x' ef_nhpi_tot`x' ef_nhpi_men`x' ef_nhpi_women`x' ///
				ef_white_tot`x' ef_white_men`x' ef_white_women`x' ///
				ef_twomore_tot`x' ef_twomore_men`x' ef_twomore_women`x' ///
				ef_unk_tot`x' ef_unk_men`x' ef_unk_women`x' ef_nra_tot`x' ///
				ef_nra_men`x' ef_nra_women`x')
				
		keep unitid year ef_*
		save "$temp\ef_`tenyear'_`mry'`x'.dta", replace
	}

	*age group
	forvalues x = `tenyear'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/EF`x'B.zip . , replace
		*unzipfile EF`x'B.zip, replace
		import delimited ef`x'b, varn(1) clear
		keep if efbage == 7															// keep age 25+
		
		foreach y in 2 5 6 {
			preserve
				capture {
					keep if lstudy == `y'
					if `y' == 2 local stud_lvl "ug"
					if `y' == 5 local stud_lvl "gr"
					if `y' == 6 local stud_lvl "prf"
					
					rename (efage01 efage02 efage03 efage04 efage05 efage06 ///
						efage07 efage08 efage09) ///
					(ef_nontrad_ft_m_`stud_lvl' ef_nontrad_ft_w_`stud_lvl' ///
						ef_nontrad_pt_m_`stud_lvl' ef_nontrad_pt_w_`stud_lvl' ///
						ef_nontrad_ft_t_`stud_lvl' ef_nontrad_pt_t_`stud_lvl' ///
						ef_nontrad_m_`stud_lvl' ef_nontrad_w_`stud_lvl' ///
						ef_nontrad_`stud_lvl')
					
					keep unitid ef_nontrad_*
					save ef_age_`x'_`stud_lvl', replace
				}
			restore
		}
		
		use ef_age_`x'_ug, clear
		capture merge 1:1 unitid using ef_age_`x'_gr
		drop _merge 
		capture merge 1:1 unitid using ef_age_`x'_prf
		drop _merge 

		gen year = "`x'"
		save "ef_age_`x'.dta", replace
	}
	
	use ef_age_`tenyear'.dta, clear 
	forvalues i = `tenyear_append'/`mry' {
		append using ef_age_`i'
	}
	
	sort unitid year
	
	foreach x in ft_m ft_w pt_m pt_w ft_t pt_t m w "" {
		if "`x'" == "" local uscore ""
		else local uscore "_"
		egen ef_nontrad_`x'`uscore'gr_1 = rowtotal(ef_nontrad_`x'`uscore'gr ef_nontrad_`x'`uscore'prf)
		drop ef_nontrad_`x'`uscore'gr ef_nontrad_`x'`uscore'prf
		rename ef_nontrad_`x'`uscore'gr_1 ef_nontrad_`x'`uscore'gr
	}
	
	egen ef_nontrad_tot = rowtotal(ef_nontrad_ug ef_nontrad_gr)

	save "$temp\ef_nontrad_`tenyear'_`mry'.dta", replace
	
	*distance ed 																	// Doesn't start until 2012
	local tenyear_dist = ${tenyear_dist}
	
	forvalues x = `tenyear_append'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/EF`x'A_DIST.zip . , replace
		*unzipfile EF`x'A_DIST.zip, replace 
		import delimited ef`x'a_dist.csv, varn(1) clear
		foreach y in 1 2 12 {														// save by student level
			if `y' == 1 	local level ""
			if `y' == 2 	local level "_ug"
			if `y' == 12 	local level "_gr"
			
			preserve
			rename (efdetot efdeexc efdesom efdenon) ///
					(dist_denom`level' dist_excl`level' dist_some`level' ///
					dist_none`level')
				keep if efdelev == `y'
				keep unitid dist*
				gen year = "`x'"
				save "ef`x'_a`level'.dta", replace
			restore 
		}
		
		use "ef`x'_a.dta", clear 
		foreach y in "_ug" "_gr" {
			merge 1:1 unitid using "ef`x'_a`y'.dta"
			drop _merge
		}
		
		save "ef_dist_`x'.dta", replace
	}
	
		// Append
			use "ef_dist_`tenyear_append'.dta", clear
			forvalues x = `tenyear_dist'/`mry' {
				append using "ef_dist_`x'.dta"
			}
			
	save "$temp\ef_dist_`tenyear_append'_`mry'.dta", replace

// Completions (degrees conferred by program, race/ethnicity, age) ------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}

	forvalues x = `tenyear'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/C`x'_A.zip . , replace
		*unzipfile C`x'_A, replace
		import delimited "c`x'_a.csv", clear
		
		rename (cnralt cnralm cnralw casiat casiam casiaw cbkaat cbkaam cbkaaw ///
				caiant caianm caianw cnhpit cnhpim cnhpiw chispt chispm chispw ///
				cwhitt cwhitm cwhitw cunknt cunknm cunknw c2mort c2morm c2morw ///
				ctotalt ctotalm ctotalw) ///
			   (r_nra_tot r_nra_men r_nra_women r_asian_tot r_asian_men ///
				r_asian_women r_black_tot r_black_men r_black_women r_native_tot ///
				r_native_men r_native_women r_nhpi_tot r_nhpi_men r_nhpi_women ///
				r_hisp_tot r_hisp_men r_hisp_women r_white_tot r_white_men ///
				r_white_women r_unk_tot r_unk_men r_unk_women r_twoplus_tot ///
				r_twoplus_men r_twoplus_women r_total_tot r_total_men r_total_women)
		
		keep if inlist(awlevel,3,5,7,9,10,17,18,19)									// assoc, bach, mast, doct, prof, doct1, doct2, doct3
		keep unitid cipcode awlevel majornum r_*									// keep relevant vars
		replace cipcode = floor(cipcode)											// reduce to 2-digit cip
		collapse (sum) r_*, by(unitid cipcode awlevel majornum)						// Sum all 6-digits to 2-digit			
		tostring cipcode, replace													// Make string for reshape
		
		levelsof awlevel, local(levels_awlevel)
		foreach z of local levels_awlevel {
			preserve 
				keep if awlevel == `z'
				keep if majornum == 1
				drop awlevel majornum
				reshape wide r_*, i(unitid) j(cipcode) string

				if `z' == 3 local deg_lev "assoc"
				if `z' == 5 local deg_lev "bach"
				if `z' == 7 local deg_lev "mast"
				if `z' == 9 local deg_lev "doct"
				if `z' == 10 local deg_lev "prof"
				if `z' == 17 local deg_lev "doct1"
				if `z' == 18 local deg_lev "doct2"
				if `z' == 19 local deg_lev "doct3"
				
				ds r_*
				foreach q of varlist `r(varlist)' {
					rename `q' comp`q'_`deg_lev'_1st
				}
				
				save comp_`x'_`deg_lev'_1st, replace
			restore
			
			preserve 
				keep if awlevel == `z'
				keep if majornum == 2
				drop awlevel majornum
				capture reshape wide r_*, i(unitid) j(cipcode) string

				if `z' == 3 local deg_lev "assoc"
				if `z' == 5 local deg_lev "bach"
				if `z' == 7 local deg_lev "mast"
				if `z' == 9 local deg_lev "doct"
				if `z' == 10 local deg_lev "prof"
				if `z' == 17 local deg_lev "doct1"
				if `z' == 18 local deg_lev "doct2"
				if `z' == 19 local deg_lev "doct3"
				if _N == 0 local deg_lev "EMPTY"								// Identify empty level/degree combos
				
				ds r_*
				foreach q of varlist `r(varlist)' {
					rename `q' comp`q'_`deg_lev'_2nd
				}
				
				save comp_`x'_`deg_lev'_2nd, replace
			restore
		}
	}
		
	forvalues x = `tenyear'/`mry' {														// new structure and 2nd degrees
		use comp_`x'_assoc_1st, clear
		cap merge 1:1 unitid using comp_`x'_assoc_2nd
		cap drop _merge 
		cap merge 1:1 unitid using comp_`x'_bach_1st
		cap drop _merge 
		cap merge 1:1 unitid using comp_`x'_bach_2nd
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_mast_1st
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_mast_2nd
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_doct1_1st
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_doct1_2nd
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_doct2_1st
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_doct2_2nd
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_doct3_1st
		cap drop _merge
		cap merge 1:1 unitid using comp_`x'_doct3_2nd
		cap drop _merge
		
		gen year = "`x'"
		save comp_`x'_allvars, replace
	}
		
		// Now keep only total conferrments by race/sex
		forvalues x = `tenyear'/`mry' {
			use comp_`x'_allvars, clear
			keep unitid year *99*
			renvars compr*, subst(99 "")
			
			local race nra black native aapi hisp white other total nhpi asian unk twoplus
			foreach y of local race {
				cap gen compr_`y'_men_assoc_1st = .									// Must create containers for future calcs (if not already there)
				cap gen compr_`y'_men_assoc_2nd = .
				cap egen compr_`y'_men_assoc = rowtotal(compr_`y'_men_assoc_1st compr_`y'_men_assoc_2nd), missing
				cap gen compr_`y'_men_assoc = .										// In case egen is empty
				
				cap gen compr_`y'_men_bach_1st = .
				cap gen compr_`y'_men_bach_2nd = .
				cap egen compr_`y'_men_bach = rowtotal(compr_`y'_men_bach_1st compr_`y'_men_bach_2nd), missing
				cap gen compr_`y'_men_bach = .
				
				cap gen compr_`y'_men_mast_1st = .
				cap gen compr_`y'_men_mast_2nd = .
				cap egen compr_`y'_men_mast = rowtotal(compr_`y'_men_mast_1st compr_`y'_men_mast_2nd), missing
				cap gen compr_`y'_men_mast = .
				
				cap gen compr_`y'_men_doct1_1st = .
				cap gen compr_`y'_men_doct1_2nd = .
				cap egen compr_`y'_men_doct1 = rowtotal(compr_`y'_men_doct1_1st compr_`y'_men_doct1_2nd), missing
				cap gen compr_`y'_men_doct1 = .
				
				cap gen compr_`y'_men_doct2_1st = .
				cap gen compr_`y'_men_doct2_2nd = .
				cap egen compr_`y'_men_doct2 = rowtotal(compr_`y'_men_doct2_1st compr_`y'_men_doct2_2nd), missing
				cap gen compr_`y'_men_doct2 = .
				
				cap gen compr_`y'_men_doct3_1st = .
				cap gen compr_`y'_men_doct3_2nd = .
				cap egen compr_`y'_men_doct3 = rowtotal(compr_`y'_men_doct3_1st compr_`y'_men_doct3_2nd), missing
				cap gen compr_`y'_men_doct3 = .
				
				
				cap gen compr_`y'_women_assoc_1st = .
				cap gen compr_`y'_women_assoc_2nd = .
				cap egen compr_`y'_women_assoc = rowtotal(compr_`y'_women_assoc_1st compr_`y'_women_assoc_2nd), missing
				cap gen compr_`y'_women_assoc = .
				
				cap gen compr_`y'_women_bach_1st = .
				cap gen compr_`y'_women_bach_2nd = .
				cap egen compr_`y'_women_bach = rowtotal(compr_`y'_women_bach_1st compr_`y'_women_bach_2nd), missing
				cap gen compr_`y'_women_bach = .
				
				cap gen compr_`y'_women_mast_1st = .
				cap gen compr_`y'_women_mast_2nd = .
				cap egen compr_`y'_women_mast = rowtotal(compr_`y'_women_mast_1st compr_`y'_women_mast_2nd), missing
				cap gen compr_`y'_women_mast = .
				
				cap gen compr_`y'_women_doct1_1st = .
				cap gen compr_`y'_women_doct1_2nd = .
				cap egen compr_`y'_women_doct1 = rowtotal(compr_`y'_women_doct1_1st compr_`y'_women_doct1_2nd), missing
				cap gen compr_`y'_women_doct1 = .
				
				cap gen compr_`y'_women_doct2_1st = .
				cap gen compr_`y'_women_doct2_2nd = .
				cap egen compr_`y'_women_doct2 = rowtotal(compr_`y'_women_doct2_1st compr_`y'_women_doct2_2nd), missing
				cap gen compr_`y'_women_doct2 = .
				
				cap gen compr_`y'_women_doct3_1st = .
				cap gen compr_`y'_women_doct3_2nd = .
				cap egen compr_`y'_women_doct3 = rowtotal(compr_`y'_women_doct3_1st compr_`y'_women_doct3_2nd), missing
				cap gen compr_`y'_women_doct3 = .
				
				cap drop compr_`y'_*_1st compr_`y'_*_2nd
				
				gen compr_`y'_men_grad = .
				cap ereplace compr_`y'_men_grad = rowtotal(compr_`y'_men_doct1 compr_`y'_men_doct2 compr_`y'_men_doct3 compr_`y'_men_mast), missing
				gen compr_`y'_women_grad = .
				cap ereplace compr_`y'_women_grad = rowtotal(compr_`y'_women_doct1 compr_`y'_women_doct2 compr_`y'_women_doct3 compr_`y'_women_mast), missing
				
				cap drop compr_`y'_*_mast compr_`y'_*_doct*
				
				foreach q in assoc bach grad {
					cap egen compr_`y'_tot_`q' = rowtotal(compr_`y'_men_`q' compr_`y'_women_`q'), missing
				}
			}
			save comp_`x'_short, replace
		}
	
	// Append all years of short versions 
		use comp_`tenyear'_short, clear 
		forvalues x = `tenyear_append'/`mry' {
			append using comp_`x'_short
		}
		
	save "$temp\comp_`tenyear'_`mry'.dta", replace


// Institutional Finances -----------------------------------------------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}

	local ending F1A F2 F3
	forvalues x = `tenyear'/`mry' {
		foreach y of local ending {
			local year_end = substr("`x'",3,2)										// pull "11" from "2011"
			local year_start = (`year_end' - 1)
			local year_comb = "`year_start'" + "`year_end'"
			*copy https://nces.ed.gov/ipeds/datacenter/data/F`year_comb'_`y'.zip . , replace
			*unzipfile F`year_comb'_`y', replace
			local suffix = strlower("`y'")											// lowercase for file name
			import delimited "f`year_comb'_`suffix'.csv", varn(1) clear
			gen year = "`x'"
			save "f`x'_`suffix'.dta", replace
		}

	// Merge & Append
		use f`x'_f1a.dta, clear
		append using f`x'_f2
		append using f`x'_f3
		
	// State appropriations
		gen state_approp = f1b11											
		replace state_approp = f2d03 if (state_approp == . & f2d03 != .)		
		replace state_approp = f3d03 if (state_approp == . & f3d03 != .)	
		sum f1b11 f2d03 f3d03 state_approp
		
	// Gross tuition revenue
		gen gross_tuition_rev = (f1b01 + f1e08)																// publics
		replace gross_tuition_rev = (f2d01 + f2c08) if (gross_tuition_rev == . & f2d01 != . & f2c08 != .)	// np
		replace gross_tuition_rev = (f3d01 + f3c06) if (gross_tuition_rev == . & f3d01 != . & f3c06 != .)	// fp

	// Institutional grant aid
		gen tot_inst_aid = f1e05 + f1e06														// publics
		replace tot_inst_aid = f2c05 + f2c06 if (tot_inst_aid == . & f2c05 != . & f2c06 != .)	// np
		replace tot_inst_aid = f3c04 if (tot_inst_aid == . & f3c04 != .)						// fp
		
	keep unitid year state_approp gross_tuition_rev tot_inst_aid
		
	save f_`x'.dta, replace
	}
	
	// Append 
		use f_`tenyear'.dta, replace
		forvalues x = `tenyear_append'/`mry' {
			append using f_`x'.dta
		}
	
		save "$temp\f_`tenyear'_`mry'.dta", replace

// Financial Aid --------------------------------------------------------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}

	forvalues x = `tenyear'/`mry' {
		local year_end = substr("`x'",3,2)											// pull "11" from "2011"
		local year_start = (`year_end' - 1)
		local year_comb = "`year_start'" + "`year_end'"
		*copy https://nces.ed.gov/ipeds/datacenter/data/SFA`year_comb'.zip . , replace
		*unzipfile SFA`year_comb'.zip, replace
		import delimited sfa`year_comb', clear 
		keep 	unitid scugffn scugrad upgrntn upgrnta ufloann ufloana ///
				fgrnt_n fgrnt_a pgrnt_n pgrnt_a ///
				floan_n floan_a
		rename 	(scugffn scugrad upgrntn upgrnta ufloann ufloana ///
					fgrnt_n fgrnt_a pgrnt_n pgrnt_a floan_n floan_a) ///
				(cohort_n ug_n ug_pell_n ug_pell_avg ug_floan_n ug_floan_avg ///
					cohort_fed_grnt_n cohort_fed_grnt_avg cohort_pell_n ///
					cohort_pell_avg cohort_floan_n cohort_floan_avg)

		gen year = "`x'"
		save "sfa_`x'.dta", replace
	}
		
	// Append
		use sfa_`tenyear'.dta, replace
		forvalues x = `tenyear_append'/`mry' {
			append using sfa_`x'.dta
		}
		
	save "$temp\sfa_`tenyear'_`mry'.dta", replace

// Graduation Rates (FTFT) ----------------------------------------------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}

	forvalues x = `tenyear'/`mry' {
		*copy https://nces.ed.gov/ipeds/datacenter/data/GR`x'.zip . , replace
		*unzipfile GR`x', replace
		import delimited "gr`x'.csv", clear
		
		rename (grtotlt grtype) (gr_total_tot gtype)
		keep unitid gtype gr_total_tot
		gen denom150_temp = gr_total_tot if inlist(gtype,2,29)
		egen denom150 = max(denom150_temp), by(unitid)
		drop denom150_temp
		keep if inlist(gtype,3,30)
		lab define gtype_lab 3 "4-year" 30 "2-year"
		lab val gtype gtype_lab

		gen year = "`x'"
		save gr`x', replace	
	}
			
	// Append
		use gr`tenyear'.dta, clear 
		forvalues x = `tenyear_append'/`mry' {
			append using gr`x'.dta
		}
		
		save "$temp\gr_`tenyear'_`mry'.dta", replace

		
********************************************************************************
**# [3] COMBINE ALL PANELS INTO ONE -------------------------------------------|
	local tenyear = ${tenyear}														// For testing purposes
	local mry = ${mry}
	local tenyear_append = ${tenyear_append}

	use "$temp\hd_`tenyear'_`mry'.dta", clear

	merge 1:1 unitid year using "$temp\tuition_`tenyear'_`mry'.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_`tenyear'_`mry'.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_`tenyear'_`mry'_ftug.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_`tenyear'_`mry'_ptug.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_`tenyear'_`mry'_ftgr.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_`tenyear'_`mry'_ptgr.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_dist_`tenyear_append'_`mry'.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\ef_nontrad_`tenyear'_`mry'"
		drop _merge
	merge 1:1 unitid year using "$temp\comp_`tenyear'_`mry'.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\f_`tenyear'_`mry'.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\sfa_`tenyear'_`mry'.dta"
		drop _merge
	merge 1:1 unitid year using "$temp\gr_`tenyear'_`mry'.dta"
		drop _merge

	
********************************************************************************
**# [4] DROP UNUSED VARS AND CLEAN --------------------------------------------|

	gen address = addr + ", " + city + ", " + stabbr + " " + zip

	drop 	addr city zip obereg-ein webaddr-npricurl hloffer-hdegofr1 ///
			hospital medical locale-pseflag rptmth-instcat ccipug-ccsizset ///
			tenursys-countynm longitud latitude f1syscod dfrcgid-athurl ///
			c15ipug-disaurl c18ipug-c18szset c21ipug-c21szset
		
	drop if inlist(sector,0,99)														// Remove admin units and non-included institutions
	
// Calculate FTE Fall enrollment													// Formula from IPEDS Glossary: https://surveys.nces.ed.gov/ipeds/public/glossary
	* Total and by race
	ds ef_*
	foreach x in `r(varlist)' {
		recode `x' (. = 0)
	}
	
	foreach y in "tot" "men" "women" {
		foreach x in "" aian_ asian_ black_ hisp_ nhpi_ white_ twomore_ unk_ nra_ {
			if ("`x'" == "") & ("`y'" != "tot") {
				local revised "tot_"
			}
			else {
				local revised ""
			}
			gen ef_`revised'`x'`y'_fte = (ef_`revised'`x'`y'_ftug + (ef_`revised'`x'`y'_ptug * 0.403543)) + ///
				(ef_`revised'`x'`y'_ftgr + (ef_`revised'`x'`y'_ptgr * 0.361702)) if inlist(sector,1)		// Public 4-Years
			
			replace ef_`revised'`x'`y'_fte = (ef_`revised'`x'`y'_ftug + (ef_`revised'`x'`y'_ptug * 0.392857)) + ///
				(ef_`revised'`x'`y'_ftgr + (ef_`revised'`x'`y'_ptgr * 0.382059)) if inlist(sector,2,3)	// 4-Year non- and for-profits
			replace ef_`revised'`x'`y'_fte = (ef_`revised'`x'`y'_ftug + (ef_`revised'`x'`y'_ptug * 0.335737)) ///
				if inlist(sector,4,7)													// Public 2- and less
			replace ef_`revised'`x'`y'_fte = (ef_`revised'`x'`y'_ftug + (ef_`revised'`x'`y'_ptug * 0.397058)) ///
				if inlist(sector,5,6,8,9)												// All others
		}
	}
			
	* Non-traditional students
	
	foreach x in t w m {
		gen ef_nontrad_`x'_fte = (ef_nontrad_ft_`x'_ug + (ef_nontrad_pt_`x'_ug * 0.403543)) + ///
			(ef_nontrad_ft_`x'_gr + (ef_nontrad_pt_`x'_gr * 0.361702)) if inlist(sector,1)		// Public 4-Years
			
		replace ef_nontrad_`x'_fte = (ef_nontrad_ft_`x'_ug + (ef_nontrad_pt_`x'_ug * 0.392857)) + ///
			(ef_nontrad_ft_`x'_gr + (ef_nontrad_pt_`x'_gr * 0.382059)) if inlist(sector,2,3)	// 4-Year non- and for-profits
			
		replace ef_nontrad_`x'_fte = (ef_nontrad_ft_`x'_ug + (ef_nontrad_pt_`x'_ug * 0.335737)) ///
			if inlist(sector,4,7)																// Public 2- and less
			
		replace ef_nontrad_`x'_fte = (ef_nontrad_ft_`x'_ug + (ef_nontrad_pt_`x'_ug * 0.397058)) ///
			if inlist(sector,5,6,8,9)															// All others
	}

	
	save "$analysis\ipeds_2011_2021.dta", replace
	
	fs "${raw}\*.zip" "${raw}\*.dta" "${raw}\*_rv.csv"								// Remove zipped folders and pre-appended .dta files from raw folder
	foreach y in `r(files)' {
		rm `y'
	}




