********************************************************************************
// Purpose: Pull in Scorecard data for 2011-2021
// Author: Jared Colston
// Last Updated: 10.17.2023
// Last Updated By: Jared Colston
********************************************************************************

clear all

********************************************************************************
**# [i] DEPENDENCIES ----------------------------------------------------------|
/* 	This .do file is stand-alone; it pulls directly from Scorecard website,
	produces a cleaned file at institution level, and removes 
	intermediary files. It can be run separately. */
	
********************************************************************************
**# [ii] USER-WRITTEN COMMANDS ------------------------------------------------|

	/*

	*/

********************************************************************************
**# [1] FILE PATHWAYS ---------------------------------------------------------|
	
	global path "C:\Users\jared\Desktop\work\pnpi\data\scorecard"						// Here you can set overall folder for Scorecard to run as stand-alone
	*capture global path "$scorecardpath"													// If you use the combined option in zipped folder
	
	*pathway key:
		*raw = untransformed files from data source
		*temp = transformed files, not ready for analysis
		*analysis = final cleaned dataframe
	
	capture mkdir "$path\raw"																// Create folders if not already made
	capture mkdir "$path\temp"
	capture mkdir "$path\backup"
	
	global raw "$path\raw"
	global temp "$path\temp"
	global backup "$path\backup"
	global analysis "$path"


********************************************************************************
**# [2] IMPORT ALL SCORECARD DATA ---------------------------------------------|

	cd "$raw"
	*copy https://ed-public-download.app.cloud.gov/downloads/CollegeScorecard_Raw_Data_09262023.zip . , replace
	*unzipfile CollegeScorecard_Raw_Data_09262023.zip, replace
	
	foreach x in 	2011_12 2012_13 2013_14 2014_15 2015_16 2016_17 2017_18 ///
					2018_19 2019_20 2020_21 {
		    
			import delimited "$raw\data\MERGED`x'_PP", clear 
			
			keep unitid opeid opeid6 instnm costt4_a costt4_p bbrr2_fed_ug_* ///
			bbrr2_fed_ugnocomp_* bbrr2_pp_ug_* bbrr2_fed_gr_n cdr3 lp* debt_mdn ///
			grad_debt_mdn wdraw_debt_mdn lo_inc_debt_mdn hi_inc_debt_mdn ///
			pbi annhi aanapii hsi nanti distanceonly npt4_pub npt4_priv ///
			npt41_pub npt45_pub npt41_priv npt45_priv num4_pub num4_priv ///
			num41_pub num41_priv num45_pub num45_priv cdr3_denom preddeg control
			
				ds, has(type string)
				foreach y in `r(varlist)' {				 
					replace `y'= "" if (`y'=="NULL" | `y'=="PrivacySuppressed")
				}
				destring *, replace
			local year = substr("`x'",1,4)
			gen year = "`year'"
			tostring opeid, replace
			save scorecard_`year', replace
		}
		
	// Now get most recent year (2021_22)
		import delimited "$raw\data\Most-Recent-Cohorts-Institution", clear 
		
		keep unitid opeid opeid6 instnm costt4_a costt4_p bbrr2_fed_ug_* ///
		bbrr2_fed_ugnocomp_* bbrr2_pp_ug_* bbrr2_fed_gr_n cdr3 lp* debt_mdn ///
		grad_debt_mdn wdraw_debt_mdn lo_inc_debt_mdn hi_inc_debt_mdn ///
		pbi annhi aanapii hsi nanti distanceonly npt4_pub npt4_priv ///
		npt41_pub npt45_pub npt41_priv npt45_priv num4_pub num4_priv ///
		num41_pub num41_priv num45_pub num45_priv cdr3_denom preddeg control
		
		ds, has(type string)
		foreach y in `r(varlist)' {				 
			replace `y'= "" if (`y'=="NULL" | `y'=="PrivacySuppressed")
		}
		destring *, replace
		
		tostring opeid, replace
		gen year = "2021"
		save scorecard_2021, replace
	
********************************************************************************
**# [3] APPEND ALL YEARS ------------------------------------------------------|
	
	use scorecard_2011.dta, clear
	forvalues i = 2012/2021 {
			append using scorecard_`i', force
		}
		
********************************************************************************
**# [4] Combine COA and Net Price metrics -------------------------------------|

	gen coa = costt4_a
	replace coa = costt4_p if coa == .
	drop costt4_a costt4_p
	
	gen netprice_tot_avg = npt4_pub
	replace netprice_tot_avg = npt4_priv if netprice_tot_avg == .
	
	gen netprice_denom = num4_pub 
	replace netprice_denom = num4_priv if netprice_denom == .
	
	gen netprice_less30_avg = npt41_pub
	replace netprice_less30_avg = npt41_priv if netprice_less30_avg == .
	
	gen netprice_less30_denom = num41_pub 
	replace netprice_less30_denom = num41_priv if netprice_less30_denom == .
	
	gen netprice_more110_avg = npt45_pub
	replace netprice_more110_avg = npt45_priv if netprice_more110_avg == .
	
	gen netprice_more110_denom = num45_pub 
	replace netprice_more110_denom = num45_priv if netprice_more110_denom == .
	
	drop npt4_pub npt4_priv npt41_pub npt45_pub npt41_priv npt45_priv ///
		num4_pub num4_priv npt41_pub npt41_priv num41_pub num41_priv ///
		num45_pub num45_priv
		

********************************************************************************
**# [4] LABELS ----------------------------------------------------------------|

// Label variables 
	lab var	unitid			"Unit ID"
	lab var	opeid			"8-digit OPE ID"
	lab var	opeid6			"6-digit OPE ID"
	lab var	instnm			"Institution name"
	lab var	distanceonly	" distance-education-only education"
	lab var	cdr3			"Three-year cohort default rate"
	lab var	debt_mdn		"The median orig. amount of the loan principal upon entering repayment"
	lab var	grad_debt_mdn	"The median debt for stdnts have comp"
	lab var	wdraw_debt_mdn	"The median debt for stdnts have not comp"
	lab var	lo_inc_debt_mdn	"The median debt for stdnts with family inc between $0-30k"
	lab var	hi_inc_debt_mdn	"The median debt for stdnts with family inc $75,001+"
	lab var	cdr3_denom			"num of stdnts in the cohort for the three-year cohort default rate"
	lab var	bbrr2_fed_ug_n					"ug fed stdnt loan borrower-based 2-year borrower count"
	lab var	bbrr2_fed_ug_dflt				"pct of ug fed stdnt loan borrowers in default after 2 years"
	lab var	bbrr2_fed_ug_dlnq				"pct of ug fed stdnt loan borrowers in delinquency after 2 years"
	lab var	bbrr2_fed_ug_fbr				"pct of ug fed stdnt loan borrowers in forbearance after 2 years"
	lab var	bbrr2_fed_ug_dfr				"pct of ug fed stdnt loan borrowers in deferment after 2 years"
	lab var	bbrr2_fed_ug_noprog				"pct of ug fed stdnt loan borrowers not making progress after 2 years"
	lab var	bbrr2_fed_ug_makeprog			"pct of ug fed stdnt loan borrowers making progress after 2 years"
	lab var	bbrr2_fed_ug_paidinfull			"pct of ug fed stdnt loan borrowers paid in full after 2 years"
	lab var	bbrr2_fed_ug_discharge			"pct of ug fed stdnt loan borrowers with all loans discharged after 2 years"
	lab var	bbrr2_fed_ugnocomp_n			"ug non-compr ug fed stdnt loan borrower-based 2-year borrower count"
	lab var	bbrr2_fed_ugnocomp_dflt			"pct of ug non-compr ug fed stdnt loan borrowers in default after 2 years"
	lab var	bbrr2_fed_ugnocomp_dlnq			"pct of ug non-compr ug fed stdnt loan borrowers in delinquency after 2 years"
	lab var	bbrr2_fed_ugnocomp_fbr			"pct of ug non-compr ug fed stdnt loan borrowers in forbearance after 2 years"
	lab var	bbrr2_fed_ugnocomp_dfr			"pct of ug non-compr ug fed stdnt loan borrowers in deferment after 2 years"
	lab var	bbrr2_fed_ugnocomp_noprog		"pct of ug non-compr ug fed stdnt loan borrowers not making progress after 2 years"
	lab var	bbrr2_fed_ugnocomp_makeprog		"pct of ug non-compr ug fed stdnt loan borrowers making progress after 2 years"
	lab var	bbrr2_fed_ugnocomp_paidinfull	"pct of ug non-compr ug fed stdnt loan borrowers paid in full after 2 years"
	lab var	bbrr2_fed_ugnocomp_discharge	"pct of ug non-compr ug fed stdnt loan borrowers with all loans discharged after 2 years"
	lab var	bbrr2_pp_ug_n					"ug stdnt Parent PLUS Loan borrower-based 2-year borrower count"
	lab var	bbrr2_pp_ug_dflt				"pct of ug stdnt Parent PLUS Loan borrowers in default after 2 years"
	lab var	bbrr2_pp_ug_dlnq				"pct of ug stdnt Parent PLUS Loan borrowers in delinquency after 2 years"
	lab var	bbrr2_pp_ug_fbr					"pct of ug stdnt Parent PLUS Loan borrowers in forbearance after 2 years"
	lab var	bbrr2_pp_ug_dfr					"pct of ug stdnt Parent PLUS Loan borrowers in deferment after 2 years"
	lab var	bbrr2_pp_ug_noprog				"pct of ug stdnt Parent PLUS Loan borrowers not making progress after 2 years"
	lab var	bbrr2_pp_ug_makeprog			"pct of ug stdnt Parent PLUS Loan borrowers making progress after 2 years"
	lab var	bbrr2_pp_ug_paidinfull			"pct of ug stdnt Parent PLUS Loan borrowers paid in full after 2 years"
	lab var	bbrr2_pp_ug_discharge			"pct of ug stdnt Parent PLUS Loan borrowers with all loans discharged after 2 years"
	lab var	lpstafford_cnt	"num of borrowers with outstanding fed Direct Loan balances"
	lab var	lpstafford_amt	"tot outstanding fed Direct Loan balance"
	lab var	lppplus_cnt		"num of stdnts associated with outstanding Parent PLUS Loan balances"
	lab var	lppplus_amt		"tot outstanding Parent PLUS Loan balance"

// Label values 
	lab define	preddeg_lab	0	"Not classified"	, add
	lab define	preddeg_lab	1	"Predominantly certificate-degree granting"	, add
	lab define	preddeg_lab	2	"Predominantly associate's-degree granting"	, add
	lab define	preddeg_lab	3	"Predominantly bachelor's-degree granting"	, add
	lab define	preddeg_lab	4	"Entirely graduate-degree granting"	, add
	lab val preddeg	preddeg_lab
	lab define	control_lab	1	"Public"	, add
	lab define	control_lab	2	"Private nonprofit"	, add
	lab define	control_lab	3	"Private for-profit"	, add
	lab val control	control_lab			


********************************************************************************
**#[5] SAVE CLEANED FILE ------------------------------------------------------|
	
	save "$analysis\scorecard_cleaned.dta", replace
	
		
		
		
		